# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MessageModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'created_timestamp': 'int',
        'external_message_id': 'str',
        'user_id': 'int',
        'content': 'str',
        'instant_app': 'InstantAppModel',
        'uploads': 'list[UploadModel]',
        'status': 'str',
        'pool_subchannel_id': 'int'
    }

    attribute_map = {
        'id': 'id',
        'created_timestamp': 'createdTimestamp',
        'external_message_id': 'externalMessageId',
        'user_id': 'userId',
        'content': 'content',
        'instant_app': 'instantApp',
        'uploads': 'uploads',
        'status': 'status',
        'pool_subchannel_id': 'poolSubchannelId'
    }

    def __init__(self, id=None, created_timestamp=None, external_message_id=None, user_id=None, content=None, instant_app=None, uploads=None, status=None, pool_subchannel_id=None):  # noqa: E501
        """MessageModel - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._created_timestamp = None
        self._external_message_id = None
        self._user_id = None
        self._content = None
        self._instant_app = None
        self._uploads = None
        self._status = None
        self._pool_subchannel_id = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if created_timestamp is not None:
            self.created_timestamp = created_timestamp
        if external_message_id is not None:
            self.external_message_id = external_message_id
        if user_id is not None:
            self.user_id = user_id
        if content is not None:
            self.content = content
        if instant_app is not None:
            self.instant_app = instant_app
        if uploads is not None:
            self.uploads = uploads
        if status is not None:
            self.status = status
        if pool_subchannel_id is not None:
            self.pool_subchannel_id = pool_subchannel_id

    @property
    def id(self):
        """Gets the id of this MessageModel.  # noqa: E501


        :return: The id of this MessageModel.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MessageModel.


        :param id: The id of this MessageModel.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def created_timestamp(self):
        """Gets the created_timestamp of this MessageModel.  # noqa: E501


        :return: The created_timestamp of this MessageModel.  # noqa: E501
        :rtype: int
        """
        return self._created_timestamp

    @created_timestamp.setter
    def created_timestamp(self, created_timestamp):
        """Sets the created_timestamp of this MessageModel.


        :param created_timestamp: The created_timestamp of this MessageModel.  # noqa: E501
        :type: int
        """

        self._created_timestamp = created_timestamp

    @property
    def external_message_id(self):
        """Gets the external_message_id of this MessageModel.  # noqa: E501


        :return: The external_message_id of this MessageModel.  # noqa: E501
        :rtype: str
        """
        return self._external_message_id

    @external_message_id.setter
    def external_message_id(self, external_message_id):
        """Sets the external_message_id of this MessageModel.


        :param external_message_id: The external_message_id of this MessageModel.  # noqa: E501
        :type: str
        """

        self._external_message_id = external_message_id

    @property
    def user_id(self):
        """Gets the user_id of this MessageModel.  # noqa: E501


        :return: The user_id of this MessageModel.  # noqa: E501
        :rtype: int
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this MessageModel.


        :param user_id: The user_id of this MessageModel.  # noqa: E501
        :type: int
        """

        self._user_id = user_id

    @property
    def content(self):
        """Gets the content of this MessageModel.  # noqa: E501


        :return: The content of this MessageModel.  # noqa: E501
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this MessageModel.


        :param content: The content of this MessageModel.  # noqa: E501
        :type: str
        """

        self._content = content

    @property
    def instant_app(self):
        """Gets the instant_app of this MessageModel.  # noqa: E501


        :return: The instant_app of this MessageModel.  # noqa: E501
        :rtype: InstantAppModel
        """
        return self._instant_app

    @instant_app.setter
    def instant_app(self, instant_app):
        """Sets the instant_app of this MessageModel.


        :param instant_app: The instant_app of this MessageModel.  # noqa: E501
        :type: InstantAppModel
        """

        self._instant_app = instant_app

    @property
    def uploads(self):
        """Gets the uploads of this MessageModel.  # noqa: E501


        :return: The uploads of this MessageModel.  # noqa: E501
        :rtype: list[UploadModel]
        """
        return self._uploads

    @uploads.setter
    def uploads(self, uploads):
        """Sets the uploads of this MessageModel.


        :param uploads: The uploads of this MessageModel.  # noqa: E501
        :type: list[UploadModel]
        """

        self._uploads = uploads

    @property
    def status(self):
        """Gets the status of this MessageModel.  # noqa: E501


        :return: The status of this MessageModel.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this MessageModel.


        :param status: The status of this MessageModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["NA", "SENT", "DELIVERED", "READ", "FAILED", "UNDELIVERED", "RECEIVED", "QUEUED", "OPTED_OUT", "ABORTED"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def pool_subchannel_id(self):
        """Gets the pool_subchannel_id of this MessageModel.  # noqa: E501


        :return: The pool_subchannel_id of this MessageModel.  # noqa: E501
        :rtype: int
        """
        return self._pool_subchannel_id

    @pool_subchannel_id.setter
    def pool_subchannel_id(self, pool_subchannel_id):
        """Sets the pool_subchannel_id of this MessageModel.


        :param pool_subchannel_id: The pool_subchannel_id of this MessageModel.  # noqa: E501
        :type: int
        """

        self._pool_subchannel_id = pool_subchannel_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MessageModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MessageModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TeamActivityModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'org_id': 'int',
        'start_time': 'str',
        'end_time': 'str',
        'group_id_filter': 'str',
        'team_member_id_filter': 'str',
        'activity_feed': 'list[TeamActivityEventModel]'
    }

    attribute_map = {
        'org_id': 'orgId',
        'start_time': 'startTime',
        'end_time': 'endTime',
        'group_id_filter': 'groupIdFilter',
        'team_member_id_filter': 'teamMemberIdFilter',
        'activity_feed': 'activityFeed'
    }

    def __init__(self, org_id=None, start_time=None, end_time=None, group_id_filter=None, team_member_id_filter=None, activity_feed=None):  # noqa: E501
        """TeamActivityModel - a model defined in Swagger"""  # noqa: E501
        self._org_id = None
        self._start_time = None
        self._end_time = None
        self._group_id_filter = None
        self._team_member_id_filter = None
        self._activity_feed = None
        self.discriminator = None
        if org_id is not None:
            self.org_id = org_id
        if start_time is not None:
            self.start_time = start_time
        if end_time is not None:
            self.end_time = end_time
        if group_id_filter is not None:
            self.group_id_filter = group_id_filter
        if team_member_id_filter is not None:
            self.team_member_id_filter = team_member_id_filter
        if activity_feed is not None:
            self.activity_feed = activity_feed

    @property
    def org_id(self):
        """Gets the org_id of this TeamActivityModel.  # noqa: E501

        The org id of this organization  # noqa: E501

        :return: The org_id of this TeamActivityModel.  # noqa: E501
        :rtype: int
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this TeamActivityModel.

        The org id of this organization  # noqa: E501

        :param org_id: The org_id of this TeamActivityModel.  # noqa: E501
        :type: int
        """

        self._org_id = org_id

    @property
    def start_time(self):
        """Gets the start_time of this TeamActivityModel.  # noqa: E501

        The starting time of the activity stream  # noqa: E501

        :return: The start_time of this TeamActivityModel.  # noqa: E501
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this TeamActivityModel.

        The starting time of the activity stream  # noqa: E501

        :param start_time: The start_time of this TeamActivityModel.  # noqa: E501
        :type: str
        """

        self._start_time = start_time

    @property
    def end_time(self):
        """Gets the end_time of this TeamActivityModel.  # noqa: E501

        The ending time of the activity stream  # noqa: E501

        :return: The end_time of this TeamActivityModel.  # noqa: E501
        :rtype: str
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this TeamActivityModel.

        The ending time of the activity stream  # noqa: E501

        :param end_time: The end_time of this TeamActivityModel.  # noqa: E501
        :type: str
        """

        self._end_time = end_time

    @property
    def group_id_filter(self):
        """Gets the group_id_filter of this TeamActivityModel.  # noqa: E501

        Optional, the group filter that was set, if any  # noqa: E501

        :return: The group_id_filter of this TeamActivityModel.  # noqa: E501
        :rtype: str
        """
        return self._group_id_filter

    @group_id_filter.setter
    def group_id_filter(self, group_id_filter):
        """Sets the group_id_filter of this TeamActivityModel.

        Optional, the group filter that was set, if any  # noqa: E501

        :param group_id_filter: The group_id_filter of this TeamActivityModel.  # noqa: E501
        :type: str
        """

        self._group_id_filter = group_id_filter

    @property
    def team_member_id_filter(self):
        """Gets the team_member_id_filter of this TeamActivityModel.  # noqa: E501

        Optional, the team member filter that was set, if any  # noqa: E501

        :return: The team_member_id_filter of this TeamActivityModel.  # noqa: E501
        :rtype: str
        """
        return self._team_member_id_filter

    @team_member_id_filter.setter
    def team_member_id_filter(self, team_member_id_filter):
        """Sets the team_member_id_filter of this TeamActivityModel.

        Optional, the team member filter that was set, if any  # noqa: E501

        :param team_member_id_filter: The team_member_id_filter of this TeamActivityModel.  # noqa: E501
        :type: str
        """

        self._team_member_id_filter = team_member_id_filter

    @property
    def activity_feed(self):
        """Gets the activity_feed of this TeamActivityModel.  # noqa: E501

        The activity stream  # noqa: E501

        :return: The activity_feed of this TeamActivityModel.  # noqa: E501
        :rtype: list[TeamActivityEventModel]
        """
        return self._activity_feed

    @activity_feed.setter
    def activity_feed(self, activity_feed):
        """Sets the activity_feed of this TeamActivityModel.

        The activity stream  # noqa: E501

        :param activity_feed: The activity_feed of this TeamActivityModel.  # noqa: E501
        :type: list[TeamActivityEventModel]
        """

        self._activity_feed = activity_feed

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TeamActivityModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TeamActivityModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AnalyticsErrorReportModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'timestamp_epoch': 'int',
        'message_delivery_failed': 'int',
        'message_delivery_undelivered': 'int',
        'instant_app_delivery_failed': 'int',
        'instant_app_delivery_undelivered': 'int',
        'instant_app_snippet_errors': 'int',
        'instant_app_action_errors': 'int',
        'api_caller_errors': 'int',
        'bulk_messages_failed': 'int',
        'bulk_messages_undelivered': 'int',
        'scheduled_message_failed': 'int',
        'scheduled_message_undelivered': 'int',
        'console_warnings': 'int',
        'console_errors': 'int',
        'total_errors': 'int'
    }

    attribute_map = {
        'timestamp_epoch': 'timestampEpoch',
        'message_delivery_failed': 'messageDeliveryFailed',
        'message_delivery_undelivered': 'messageDeliveryUndelivered',
        'instant_app_delivery_failed': 'instantAppDeliveryFailed',
        'instant_app_delivery_undelivered': 'instantAppDeliveryUndelivered',
        'instant_app_snippet_errors': 'instantAppSnippetErrors',
        'instant_app_action_errors': 'instantAppActionErrors',
        'api_caller_errors': 'apiCallerErrors',
        'bulk_messages_failed': 'bulkMessagesFailed',
        'bulk_messages_undelivered': 'bulkMessagesUndelivered',
        'scheduled_message_failed': 'scheduledMessageFailed',
        'scheduled_message_undelivered': 'scheduledMessageUndelivered',
        'console_warnings': 'consoleWarnings',
        'console_errors': 'consoleErrors',
        'total_errors': 'totalErrors'
    }

    def __init__(self, timestamp_epoch=None, message_delivery_failed=None, message_delivery_undelivered=None, instant_app_delivery_failed=None, instant_app_delivery_undelivered=None, instant_app_snippet_errors=None, instant_app_action_errors=None, api_caller_errors=None, bulk_messages_failed=None, bulk_messages_undelivered=None, scheduled_message_failed=None, scheduled_message_undelivered=None, console_warnings=None, console_errors=None, total_errors=None):  # noqa: E501
        """AnalyticsErrorReportModel - a model defined in Swagger"""  # noqa: E501
        self._timestamp_epoch = None
        self._message_delivery_failed = None
        self._message_delivery_undelivered = None
        self._instant_app_delivery_failed = None
        self._instant_app_delivery_undelivered = None
        self._instant_app_snippet_errors = None
        self._instant_app_action_errors = None
        self._api_caller_errors = None
        self._bulk_messages_failed = None
        self._bulk_messages_undelivered = None
        self._scheduled_message_failed = None
        self._scheduled_message_undelivered = None
        self._console_warnings = None
        self._console_errors = None
        self._total_errors = None
        self.discriminator = None
        if timestamp_epoch is not None:
            self.timestamp_epoch = timestamp_epoch
        if message_delivery_failed is not None:
            self.message_delivery_failed = message_delivery_failed
        if message_delivery_undelivered is not None:
            self.message_delivery_undelivered = message_delivery_undelivered
        if instant_app_delivery_failed is not None:
            self.instant_app_delivery_failed = instant_app_delivery_failed
        if instant_app_delivery_undelivered is not None:
            self.instant_app_delivery_undelivered = instant_app_delivery_undelivered
        if instant_app_snippet_errors is not None:
            self.instant_app_snippet_errors = instant_app_snippet_errors
        if instant_app_action_errors is not None:
            self.instant_app_action_errors = instant_app_action_errors
        if api_caller_errors is not None:
            self.api_caller_errors = api_caller_errors
        if bulk_messages_failed is not None:
            self.bulk_messages_failed = bulk_messages_failed
        if bulk_messages_undelivered is not None:
            self.bulk_messages_undelivered = bulk_messages_undelivered
        if scheduled_message_failed is not None:
            self.scheduled_message_failed = scheduled_message_failed
        if scheduled_message_undelivered is not None:
            self.scheduled_message_undelivered = scheduled_message_undelivered
        if console_warnings is not None:
            self.console_warnings = console_warnings
        if console_errors is not None:
            self.console_errors = console_errors
        if total_errors is not None:
            self.total_errors = total_errors

    @property
    def timestamp_epoch(self):
        """Gets the timestamp_epoch of this AnalyticsErrorReportModel.  # noqa: E501

        The timestamp at the start of the default group-by window as a Unix timestamp.  # noqa: E501

        :return: The timestamp_epoch of this AnalyticsErrorReportModel.  # noqa: E501
        :rtype: int
        """
        return self._timestamp_epoch

    @timestamp_epoch.setter
    def timestamp_epoch(self, timestamp_epoch):
        """Sets the timestamp_epoch of this AnalyticsErrorReportModel.

        The timestamp at the start of the default group-by window as a Unix timestamp.  # noqa: E501

        :param timestamp_epoch: The timestamp_epoch of this AnalyticsErrorReportModel.  # noqa: E501
        :type: int
        """

        self._timestamp_epoch = timestamp_epoch

    @property
    def message_delivery_failed(self):
        """Gets the message_delivery_failed of this AnalyticsErrorReportModel.  # noqa: E501

        The number of Messages which failed with status 'FAILED' in this group-by window.  # noqa: E501

        :return: The message_delivery_failed of this AnalyticsErrorReportModel.  # noqa: E501
        :rtype: int
        """
        return self._message_delivery_failed

    @message_delivery_failed.setter
    def message_delivery_failed(self, message_delivery_failed):
        """Sets the message_delivery_failed of this AnalyticsErrorReportModel.

        The number of Messages which failed with status 'FAILED' in this group-by window.  # noqa: E501

        :param message_delivery_failed: The message_delivery_failed of this AnalyticsErrorReportModel.  # noqa: E501
        :type: int
        """

        self._message_delivery_failed = message_delivery_failed

    @property
    def message_delivery_undelivered(self):
        """Gets the message_delivery_undelivered of this AnalyticsErrorReportModel.  # noqa: E501

        The number of Messages which failed with status 'UNDELIVERABLE' in this group-by window.  # noqa: E501

        :return: The message_delivery_undelivered of this AnalyticsErrorReportModel.  # noqa: E501
        :rtype: int
        """
        return self._message_delivery_undelivered

    @message_delivery_undelivered.setter
    def message_delivery_undelivered(self, message_delivery_undelivered):
        """Sets the message_delivery_undelivered of this AnalyticsErrorReportModel.

        The number of Messages which failed with status 'UNDELIVERABLE' in this group-by window.  # noqa: E501

        :param message_delivery_undelivered: The message_delivery_undelivered of this AnalyticsErrorReportModel.  # noqa: E501
        :type: int
        """

        self._message_delivery_undelivered = message_delivery_undelivered

    @property
    def instant_app_delivery_failed(self):
        """Gets the instant_app_delivery_failed of this AnalyticsErrorReportModel.  # noqa: E501

        The number of Instant Apps which failed with status 'FAILED' in this group-by window.  # noqa: E501

        :return: The instant_app_delivery_failed of this AnalyticsErrorReportModel.  # noqa: E501
        :rtype: int
        """
        return self._instant_app_delivery_failed

    @instant_app_delivery_failed.setter
    def instant_app_delivery_failed(self, instant_app_delivery_failed):
        """Sets the instant_app_delivery_failed of this AnalyticsErrorReportModel.

        The number of Instant Apps which failed with status 'FAILED' in this group-by window.  # noqa: E501

        :param instant_app_delivery_failed: The instant_app_delivery_failed of this AnalyticsErrorReportModel.  # noqa: E501
        :type: int
        """

        self._instant_app_delivery_failed = instant_app_delivery_failed

    @property
    def instant_app_delivery_undelivered(self):
        """Gets the instant_app_delivery_undelivered of this AnalyticsErrorReportModel.  # noqa: E501

        The number of Instant Apps which failed with status 'UNDELIVERABLE' in this group-by window.  # noqa: E501

        :return: The instant_app_delivery_undelivered of this AnalyticsErrorReportModel.  # noqa: E501
        :rtype: int
        """
        return self._instant_app_delivery_undelivered

    @instant_app_delivery_undelivered.setter
    def instant_app_delivery_undelivered(self, instant_app_delivery_undelivered):
        """Sets the instant_app_delivery_undelivered of this AnalyticsErrorReportModel.

        The number of Instant Apps which failed with status 'UNDELIVERABLE' in this group-by window.  # noqa: E501

        :param instant_app_delivery_undelivered: The instant_app_delivery_undelivered of this AnalyticsErrorReportModel.  # noqa: E501
        :type: int
        """

        self._instant_app_delivery_undelivered = instant_app_delivery_undelivered

    @property
    def instant_app_snippet_errors(self):
        """Gets the instant_app_snippet_errors of this AnalyticsErrorReportModel.  # noqa: E501

        The number of Snippet executions which failed with any error in this group-by window.  # noqa: E501

        :return: The instant_app_snippet_errors of this AnalyticsErrorReportModel.  # noqa: E501
        :rtype: int
        """
        return self._instant_app_snippet_errors

    @instant_app_snippet_errors.setter
    def instant_app_snippet_errors(self, instant_app_snippet_errors):
        """Sets the instant_app_snippet_errors of this AnalyticsErrorReportModel.

        The number of Snippet executions which failed with any error in this group-by window.  # noqa: E501

        :param instant_app_snippet_errors: The instant_app_snippet_errors of this AnalyticsErrorReportModel.  # noqa: E501
        :type: int
        """

        self._instant_app_snippet_errors = instant_app_snippet_errors

    @property
    def instant_app_action_errors(self):
        """Gets the instant_app_action_errors of this AnalyticsErrorReportModel.  # noqa: E501

        The number of Action executions which failed with any error in this group-by window.  # noqa: E501

        :return: The instant_app_action_errors of this AnalyticsErrorReportModel.  # noqa: E501
        :rtype: int
        """
        return self._instant_app_action_errors

    @instant_app_action_errors.setter
    def instant_app_action_errors(self, instant_app_action_errors):
        """Sets the instant_app_action_errors of this AnalyticsErrorReportModel.

        The number of Action executions which failed with any error in this group-by window.  # noqa: E501

        :param instant_app_action_errors: The instant_app_action_errors of this AnalyticsErrorReportModel.  # noqa: E501
        :type: int
        """

        self._instant_app_action_errors = instant_app_action_errors

    @property
    def api_caller_errors(self):
        """Gets the api_caller_errors of this AnalyticsErrorReportModel.  # noqa: E501

        The number of API calls which returned any non-200 response in this group-by window.  # noqa: E501

        :return: The api_caller_errors of this AnalyticsErrorReportModel.  # noqa: E501
        :rtype: int
        """
        return self._api_caller_errors

    @api_caller_errors.setter
    def api_caller_errors(self, api_caller_errors):
        """Sets the api_caller_errors of this AnalyticsErrorReportModel.

        The number of API calls which returned any non-200 response in this group-by window.  # noqa: E501

        :param api_caller_errors: The api_caller_errors of this AnalyticsErrorReportModel.  # noqa: E501
        :type: int
        """

        self._api_caller_errors = api_caller_errors

    @property
    def bulk_messages_failed(self):
        """Gets the bulk_messages_failed of this AnalyticsErrorReportModel.  # noqa: E501

        The number of Bulk Messages which failed with status 'FAILED' in this group-by window.  # noqa: E501

        :return: The bulk_messages_failed of this AnalyticsErrorReportModel.  # noqa: E501
        :rtype: int
        """
        return self._bulk_messages_failed

    @bulk_messages_failed.setter
    def bulk_messages_failed(self, bulk_messages_failed):
        """Sets the bulk_messages_failed of this AnalyticsErrorReportModel.

        The number of Bulk Messages which failed with status 'FAILED' in this group-by window.  # noqa: E501

        :param bulk_messages_failed: The bulk_messages_failed of this AnalyticsErrorReportModel.  # noqa: E501
        :type: int
        """

        self._bulk_messages_failed = bulk_messages_failed

    @property
    def bulk_messages_undelivered(self):
        """Gets the bulk_messages_undelivered of this AnalyticsErrorReportModel.  # noqa: E501

        The number of Bulk Messages which failed with status 'UNDELIVERED' in this group-by window.  # noqa: E501

        :return: The bulk_messages_undelivered of this AnalyticsErrorReportModel.  # noqa: E501
        :rtype: int
        """
        return self._bulk_messages_undelivered

    @bulk_messages_undelivered.setter
    def bulk_messages_undelivered(self, bulk_messages_undelivered):
        """Sets the bulk_messages_undelivered of this AnalyticsErrorReportModel.

        The number of Bulk Messages which failed with status 'UNDELIVERED' in this group-by window.  # noqa: E501

        :param bulk_messages_undelivered: The bulk_messages_undelivered of this AnalyticsErrorReportModel.  # noqa: E501
        :type: int
        """

        self._bulk_messages_undelivered = bulk_messages_undelivered

    @property
    def scheduled_message_failed(self):
        """Gets the scheduled_message_failed of this AnalyticsErrorReportModel.  # noqa: E501

        The number of Scheduled Messages which failed with status 'FAILED' in this group-by window.  # noqa: E501

        :return: The scheduled_message_failed of this AnalyticsErrorReportModel.  # noqa: E501
        :rtype: int
        """
        return self._scheduled_message_failed

    @scheduled_message_failed.setter
    def scheduled_message_failed(self, scheduled_message_failed):
        """Sets the scheduled_message_failed of this AnalyticsErrorReportModel.

        The number of Scheduled Messages which failed with status 'FAILED' in this group-by window.  # noqa: E501

        :param scheduled_message_failed: The scheduled_message_failed of this AnalyticsErrorReportModel.  # noqa: E501
        :type: int
        """

        self._scheduled_message_failed = scheduled_message_failed

    @property
    def scheduled_message_undelivered(self):
        """Gets the scheduled_message_undelivered of this AnalyticsErrorReportModel.  # noqa: E501

        The number of Scheduled Messages which failed with status 'UNDELIVERED' in this group-by window.  # noqa: E501

        :return: The scheduled_message_undelivered of this AnalyticsErrorReportModel.  # noqa: E501
        :rtype: int
        """
        return self._scheduled_message_undelivered

    @scheduled_message_undelivered.setter
    def scheduled_message_undelivered(self, scheduled_message_undelivered):
        """Sets the scheduled_message_undelivered of this AnalyticsErrorReportModel.

        The number of Scheduled Messages which failed with status 'UNDELIVERED' in this group-by window.  # noqa: E501

        :param scheduled_message_undelivered: The scheduled_message_undelivered of this AnalyticsErrorReportModel.  # noqa: E501
        :type: int
        """

        self._scheduled_message_undelivered = scheduled_message_undelivered

    @property
    def console_warnings(self):
        """Gets the console_warnings of this AnalyticsErrorReportModel.  # noqa: E501

        The number of console warnings in this group-by window.  # noqa: E501

        :return: The console_warnings of this AnalyticsErrorReportModel.  # noqa: E501
        :rtype: int
        """
        return self._console_warnings

    @console_warnings.setter
    def console_warnings(self, console_warnings):
        """Sets the console_warnings of this AnalyticsErrorReportModel.

        The number of console warnings in this group-by window.  # noqa: E501

        :param console_warnings: The console_warnings of this AnalyticsErrorReportModel.  # noqa: E501
        :type: int
        """

        self._console_warnings = console_warnings

    @property
    def console_errors(self):
        """Gets the console_errors of this AnalyticsErrorReportModel.  # noqa: E501

        The number of console errors in this group-by window.  # noqa: E501

        :return: The console_errors of this AnalyticsErrorReportModel.  # noqa: E501
        :rtype: int
        """
        return self._console_errors

    @console_errors.setter
    def console_errors(self, console_errors):
        """Sets the console_errors of this AnalyticsErrorReportModel.

        The number of console errors in this group-by window.  # noqa: E501

        :param console_errors: The console_errors of this AnalyticsErrorReportModel.  # noqa: E501
        :type: int
        """

        self._console_errors = console_errors

    @property
    def total_errors(self):
        """Gets the total_errors of this AnalyticsErrorReportModel.  # noqa: E501

        The total number of errors of all tracked types in this group-by window.  # noqa: E501

        :return: The total_errors of this AnalyticsErrorReportModel.  # noqa: E501
        :rtype: int
        """
        return self._total_errors

    @total_errors.setter
    def total_errors(self, total_errors):
        """Sets the total_errors of this AnalyticsErrorReportModel.

        The total number of errors of all tracked types in this group-by window.  # noqa: E501

        :param total_errors: The total_errors of this AnalyticsErrorReportModel.  # noqa: E501
        :type: int
        """

        self._total_errors = total_errors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AnalyticsErrorReportModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyticsErrorReportModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InstantAppSchemaModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'schema_api_id': 'str',
        'name': 'str',
        'author': 'str',
        'description': 'str',
        'icon': 'str',
        'active': 'bool',
        'parameters': 'list[str]',
        'type': 'str'
    }

    attribute_map = {
        'id': 'id',
        'schema_api_id': 'schemaApiId',
        'name': 'name',
        'author': 'author',
        'description': 'description',
        'icon': 'icon',
        'active': 'active',
        'parameters': 'parameters',
        'type': 'type'
    }

    def __init__(self, id=None, schema_api_id=None, name=None, author=None, description=None, icon=None, active=None, parameters=None, type=None):  # noqa: E501
        """InstantAppSchemaModel - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._schema_api_id = None
        self._name = None
        self._author = None
        self._description = None
        self._icon = None
        self._active = None
        self._parameters = None
        self._type = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if schema_api_id is not None:
            self.schema_api_id = schema_api_id
        if name is not None:
            self.name = name
        if author is not None:
            self.author = author
        if description is not None:
            self.description = description
        if icon is not None:
            self.icon = icon
        if active is not None:
            self.active = active
        if parameters is not None:
            self.parameters = parameters
        if type is not None:
            self.type = type

    @property
    def id(self):
        """Gets the id of this InstantAppSchemaModel.  # noqa: E501

        The system generated unique id for this Instant App Schema.  # noqa: E501

        :return: The id of this InstantAppSchemaModel.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InstantAppSchemaModel.

        The system generated unique id for this Instant App Schema.  # noqa: E501

        :param id: The id of this InstantAppSchemaModel.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def schema_api_id(self):
        """Gets the schema_api_id of this InstantAppSchemaModel.  # noqa: E501

        The programmatic, unique id of the schema for this Instant App Schema.  # noqa: E501

        :return: The schema_api_id of this InstantAppSchemaModel.  # noqa: E501
        :rtype: str
        """
        return self._schema_api_id

    @schema_api_id.setter
    def schema_api_id(self, schema_api_id):
        """Sets the schema_api_id of this InstantAppSchemaModel.

        The programmatic, unique id of the schema for this Instant App Schema.  # noqa: E501

        :param schema_api_id: The schema_api_id of this InstantAppSchemaModel.  # noqa: E501
        :type: str
        """

        self._schema_api_id = schema_api_id

    @property
    def name(self):
        """Gets the name of this InstantAppSchemaModel.  # noqa: E501

        The name of this Instant App Schema.  # noqa: E501

        :return: The name of this InstantAppSchemaModel.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InstantAppSchemaModel.

        The name of this Instant App Schema.  # noqa: E501

        :param name: The name of this InstantAppSchemaModel.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def author(self):
        """Gets the author of this InstantAppSchemaModel.  # noqa: E501

        The author of the Instant App Schema  # noqa: E501

        :return: The author of this InstantAppSchemaModel.  # noqa: E501
        :rtype: str
        """
        return self._author

    @author.setter
    def author(self, author):
        """Sets the author of this InstantAppSchemaModel.

        The author of the Instant App Schema  # noqa: E501

        :param author: The author of this InstantAppSchemaModel.  # noqa: E501
        :type: str
        """

        self._author = author

    @property
    def description(self):
        """Gets the description of this InstantAppSchemaModel.  # noqa: E501

        The description of the Instant App Schema  # noqa: E501

        :return: The description of this InstantAppSchemaModel.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this InstantAppSchemaModel.

        The description of the Instant App Schema  # noqa: E501

        :param description: The description of this InstantAppSchemaModel.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def icon(self):
        """Gets the icon of this InstantAppSchemaModel.  # noqa: E501

        The icon of the Instant App Schema  # noqa: E501

        :return: The icon of this InstantAppSchemaModel.  # noqa: E501
        :rtype: str
        """
        return self._icon

    @icon.setter
    def icon(self, icon):
        """Sets the icon of this InstantAppSchemaModel.

        The icon of the Instant App Schema  # noqa: E501

        :param icon: The icon of this InstantAppSchemaModel.  # noqa: E501
        :type: str
        """

        self._icon = icon

    @property
    def active(self):
        """Gets the active of this InstantAppSchemaModel.  # noqa: E501

        Whether the Instant App Schema is active  # noqa: E501

        :return: The active of this InstantAppSchemaModel.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this InstantAppSchemaModel.

        Whether the Instant App Schema is active  # noqa: E501

        :param active: The active of this InstantAppSchemaModel.  # noqa: E501
        :type: bool
        """

        self._active = active

    @property
    def parameters(self):
        """Gets the parameters of this InstantAppSchemaModel.  # noqa: E501

        List of parameters that can be configured when an Instant App instance is created  # noqa: E501

        :return: The parameters of this InstantAppSchemaModel.  # noqa: E501
        :rtype: list[str]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this InstantAppSchemaModel.

        List of parameters that can be configured when an Instant App instance is created  # noqa: E501

        :param parameters: The parameters of this InstantAppSchemaModel.  # noqa: E501
        :type: list[str]
        """

        self._parameters = parameters

    @property
    def type(self):
        """Gets the type of this InstantAppSchemaModel.  # noqa: E501

        The type of this Instant App Schema.  # noqa: E501

        :return: The type of this InstantAppSchemaModel.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this InstantAppSchemaModel.

        The type of this Instant App Schema.  # noqa: E501

        :param type: The type of this InstantAppSchemaModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["UNKNOWN", "CUSTOMER", "AGENT_PRIVATE", "AGENT_SHARED", "CHANNEL", "CHANNEL_SHARED", "OVERLAY_PRIVATE", "OVERLAY_SHARED"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InstantAppSchemaModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InstantAppSchemaModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TwilioIntegrationModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'twilio_account_sid': 'str',
        'twilio_auth_token': 'str',
        'clnpc_approved': 'bool'
    }

    attribute_map = {
        'twilio_account_sid': 'twilioAccountSID',
        'twilio_auth_token': 'twilioAuthToken',
        'clnpc_approved': 'clnpcApproved'
    }

    def __init__(self, twilio_account_sid=None, twilio_auth_token=None, clnpc_approved=None):  # noqa: E501
        """TwilioIntegrationModel - a model defined in Swagger"""  # noqa: E501
        self._twilio_account_sid = None
        self._twilio_auth_token = None
        self._clnpc_approved = None
        self.discriminator = None
        if twilio_account_sid is not None:
            self.twilio_account_sid = twilio_account_sid
        if twilio_auth_token is not None:
            self.twilio_auth_token = twilio_auth_token
        if clnpc_approved is not None:
            self.clnpc_approved = clnpc_approved

    @property
    def twilio_account_sid(self):
        """Gets the twilio_account_sid of this TwilioIntegrationModel.  # noqa: E501

        Twilio Account SID  # noqa: E501

        :return: The twilio_account_sid of this TwilioIntegrationModel.  # noqa: E501
        :rtype: str
        """
        return self._twilio_account_sid

    @twilio_account_sid.setter
    def twilio_account_sid(self, twilio_account_sid):
        """Sets the twilio_account_sid of this TwilioIntegrationModel.

        Twilio Account SID  # noqa: E501

        :param twilio_account_sid: The twilio_account_sid of this TwilioIntegrationModel.  # noqa: E501
        :type: str
        """

        self._twilio_account_sid = twilio_account_sid

    @property
    def twilio_auth_token(self):
        """Gets the twilio_auth_token of this TwilioIntegrationModel.  # noqa: E501

        Twilio Auth Token  # noqa: E501

        :return: The twilio_auth_token of this TwilioIntegrationModel.  # noqa: E501
        :rtype: str
        """
        return self._twilio_auth_token

    @twilio_auth_token.setter
    def twilio_auth_token(self, twilio_auth_token):
        """Sets the twilio_auth_token of this TwilioIntegrationModel.

        Twilio Auth Token  # noqa: E501

        :param twilio_auth_token: The twilio_auth_token of this TwilioIntegrationModel.  # noqa: E501
        :type: str
        """

        self._twilio_auth_token = twilio_auth_token

    @property
    def clnpc_approved(self):
        """Gets the clnpc_approved of this TwilioIntegrationModel.  # noqa: E501

        CLNPC approval has been received from Twilio for scrubbing Canadian numbers  # noqa: E501

        :return: The clnpc_approved of this TwilioIntegrationModel.  # noqa: E501
        :rtype: bool
        """
        return self._clnpc_approved

    @clnpc_approved.setter
    def clnpc_approved(self, clnpc_approved):
        """Sets the clnpc_approved of this TwilioIntegrationModel.

        CLNPC approval has been received from Twilio for scrubbing Canadian numbers  # noqa: E501

        :param clnpc_approved: The clnpc_approved of this TwilioIntegrationModel.  # noqa: E501
        :type: bool
        """

        self._clnpc_approved = clnpc_approved

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TwilioIntegrationModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TwilioIntegrationModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from swagger_client.api.api_keys_api import APIKeysApi
from swagger_client.api.analytics_api import AnalyticsApi
from swagger_client.api.automations_api import AutomationsApi
from swagger_client.api.bots_api import BotsApi
from swagger_client.api.bulk_actions_api import BulkActionsApi
from swagger_client.api.channel_id_integration_api import ChannelIdIntegrationApi
from swagger_client.api.contact_list_contacts_api import ContactListContactsApi
from swagger_client.api.contact_lists_api import ContactListsApi
from swagger_client.api.conversations_api import ConversationsApi
from swagger_client.api.customers_api import CustomersApi
from swagger_client.api.data_api import DataApi
from swagger_client.api.event_endpoints_api import EventEndpointsApi
from swagger_client.api.group_members_api import GroupMembersApi
from swagger_client.api.groups_api import GroupsApi
from swagger_client.api.instant_app_schemas_api import InstantAppSchemasApi
from swagger_client.api.instant_apps_api import InstantAppsApi
from swagger_client.api.integrations_api import IntegrationsApi
from swagger_client.api.maps_api import MapsApi
from swagger_client.api.messages_api import MessagesApi
from swagger_client.api.org_channels_api import OrgChannelsApi
from swagger_client.api.org_settings_api import OrgSettingsApi
from swagger_client.api.orgs_api import OrgsApi
from swagger_client.api.pool_channels_api import PoolChannelsApi
from swagger_client.api.pools_api import PoolsApi
from swagger_client.api.pounces_api import PouncesApi
from swagger_client.api.presence_api import PresenceApi
from swagger_client.api.scheduled_actions_api import ScheduledActionsApi
from swagger_client.api.smart_links_api import SmartLinksApi
from swagger_client.api.tag_groups_api import TagGroupsApi
from swagger_client.api.tags_api import TagsApi
from swagger_client.api.team_members_api import TeamMembersApi
from swagger_client.api.uploads_api import UploadsApi



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class FacebookOrgChannelModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'facebook_app_secret': 'str',
        'page_access_token': 'str',
        'verification_token': 'str',
        'facebook_app_id': 'str'
    }

    attribute_map = {
        'facebook_app_secret': 'facebookAppSecret',
        'page_access_token': 'pageAccessToken',
        'verification_token': 'verificationToken',
        'facebook_app_id': 'facebookAppId'
    }

    def __init__(self, facebook_app_secret=None, page_access_token=None, verification_token=None, facebook_app_id=None):  # noqa: E501
        """FacebookOrgChannelModel - a model defined in Swagger"""  # noqa: E501
        self._facebook_app_secret = None
        self._page_access_token = None
        self._verification_token = None
        self._facebook_app_id = None
        self.discriminator = None
        if facebook_app_secret is not None:
            self.facebook_app_secret = facebook_app_secret
        if page_access_token is not None:
            self.page_access_token = page_access_token
        if verification_token is not None:
            self.verification_token = verification_token
        if facebook_app_id is not None:
            self.facebook_app_id = facebook_app_id

    @property
    def facebook_app_secret(self):
        """Gets the facebook_app_secret of this FacebookOrgChannelModel.  # noqa: E501

        The secret given by facebook for an created app  # noqa: E501

        :return: The facebook_app_secret of this FacebookOrgChannelModel.  # noqa: E501
        :rtype: str
        """
        return self._facebook_app_secret

    @facebook_app_secret.setter
    def facebook_app_secret(self, facebook_app_secret):
        """Sets the facebook_app_secret of this FacebookOrgChannelModel.

        The secret given by facebook for an created app  # noqa: E501

        :param facebook_app_secret: The facebook_app_secret of this FacebookOrgChannelModel.  # noqa: E501
        :type: str
        """

        self._facebook_app_secret = facebook_app_secret

    @property
    def page_access_token(self):
        """Gets the page_access_token of this FacebookOrgChannelModel.  # noqa: E501

        The page access token from a facebook page  # noqa: E501

        :return: The page_access_token of this FacebookOrgChannelModel.  # noqa: E501
        :rtype: str
        """
        return self._page_access_token

    @page_access_token.setter
    def page_access_token(self, page_access_token):
        """Sets the page_access_token of this FacebookOrgChannelModel.

        The page access token from a facebook page  # noqa: E501

        :param page_access_token: The page_access_token of this FacebookOrgChannelModel.  # noqa: E501
        :type: str
        """

        self._page_access_token = page_access_token

    @property
    def verification_token(self):
        """Gets the verification_token of this FacebookOrgChannelModel.  # noqa: E501

        The Prompt.io supplied value to enter into the Facebook app for API verification  # noqa: E501

        :return: The verification_token of this FacebookOrgChannelModel.  # noqa: E501
        :rtype: str
        """
        return self._verification_token

    @verification_token.setter
    def verification_token(self, verification_token):
        """Sets the verification_token of this FacebookOrgChannelModel.

        The Prompt.io supplied value to enter into the Facebook app for API verification  # noqa: E501

        :param verification_token: The verification_token of this FacebookOrgChannelModel.  # noqa: E501
        :type: str
        """

        self._verification_token = verification_token

    @property
    def facebook_app_id(self):
        """Gets the facebook_app_id of this FacebookOrgChannelModel.  # noqa: E501

        The facebook id for the messaging app. This is the 'channel key'  # noqa: E501

        :return: The facebook_app_id of this FacebookOrgChannelModel.  # noqa: E501
        :rtype: str
        """
        return self._facebook_app_id

    @facebook_app_id.setter
    def facebook_app_id(self, facebook_app_id):
        """Sets the facebook_app_id of this FacebookOrgChannelModel.

        The facebook id for the messaging app. This is the 'channel key'  # noqa: E501

        :param facebook_app_id: The facebook_app_id of this FacebookOrgChannelModel.  # noqa: E501
        :type: str
        """

        self._facebook_app_id = facebook_app_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FacebookOrgChannelModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FacebookOrgChannelModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class EventEndpointModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'name': 'str',
        'endpoint': 'str',
        'active': 'bool',
        'creator_id': 'int',
        'created_timestamp': 'int',
        'auth_last_modified_user_id': 'int',
        'auth_last_modified_timestamp': 'int',
        'auth_type': 'str',
        'basic_auth_username': 'str',
        'basic_auth_password': 'str',
        'x_hub_signature_secret': 'str',
        'x_hub_signature_data': 'str',
        'events': 'list[str]',
        'custom_headers': 'list[KeyValueDataModel]'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'endpoint': 'endpoint',
        'active': 'active',
        'creator_id': 'creatorId',
        'created_timestamp': 'createdTimestamp',
        'auth_last_modified_user_id': 'authLastModifiedUserId',
        'auth_last_modified_timestamp': 'authLastModifiedTimestamp',
        'auth_type': 'authType',
        'basic_auth_username': 'basicAuthUsername',
        'basic_auth_password': 'basicAuthPassword',
        'x_hub_signature_secret': 'xHubSignatureSecret',
        'x_hub_signature_data': 'xHubSignatureData',
        'events': 'events',
        'custom_headers': 'customHeaders'
    }

    def __init__(self, id=None, name=None, endpoint=None, active=None, creator_id=None, created_timestamp=None, auth_last_modified_user_id=None, auth_last_modified_timestamp=None, auth_type=None, basic_auth_username=None, basic_auth_password=None, x_hub_signature_secret=None, x_hub_signature_data=None, events=None, custom_headers=None):  # noqa: E501
        """EventEndpointModel - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._endpoint = None
        self._active = None
        self._creator_id = None
        self._created_timestamp = None
        self._auth_last_modified_user_id = None
        self._auth_last_modified_timestamp = None
        self._auth_type = None
        self._basic_auth_username = None
        self._basic_auth_password = None
        self._x_hub_signature_secret = None
        self._x_hub_signature_data = None
        self._events = None
        self._custom_headers = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if endpoint is not None:
            self.endpoint = endpoint
        if active is not None:
            self.active = active
        if creator_id is not None:
            self.creator_id = creator_id
        if created_timestamp is not None:
            self.created_timestamp = created_timestamp
        if auth_last_modified_user_id is not None:
            self.auth_last_modified_user_id = auth_last_modified_user_id
        if auth_last_modified_timestamp is not None:
            self.auth_last_modified_timestamp = auth_last_modified_timestamp
        if auth_type is not None:
            self.auth_type = auth_type
        if basic_auth_username is not None:
            self.basic_auth_username = basic_auth_username
        if basic_auth_password is not None:
            self.basic_auth_password = basic_auth_password
        if x_hub_signature_secret is not None:
            self.x_hub_signature_secret = x_hub_signature_secret
        if x_hub_signature_data is not None:
            self.x_hub_signature_data = x_hub_signature_data
        if events is not None:
            self.events = events
        if custom_headers is not None:
            self.custom_headers = custom_headers

    @property
    def id(self):
        """Gets the id of this EventEndpointModel.  # noqa: E501

        The system generated unique id for this Event Endpoint.  # noqa: E501

        :return: The id of this EventEndpointModel.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this EventEndpointModel.

        The system generated unique id for this Event Endpoint.  # noqa: E501

        :param id: The id of this EventEndpointModel.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this EventEndpointModel.  # noqa: E501

        A descriptive name for this Event Endpoint to show in agent UIs.  # noqa: E501

        :return: The name of this EventEndpointModel.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this EventEndpointModel.

        A descriptive name for this Event Endpoint to show in agent UIs.  # noqa: E501

        :param name: The name of this EventEndpointModel.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def endpoint(self):
        """Gets the endpoint of this EventEndpointModel.  # noqa: E501

        Endpoint url to call when an event occurs.  # noqa: E501

        :return: The endpoint of this EventEndpointModel.  # noqa: E501
        :rtype: str
        """
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        """Sets the endpoint of this EventEndpointModel.

        Endpoint url to call when an event occurs.  # noqa: E501

        :param endpoint: The endpoint of this EventEndpointModel.  # noqa: E501
        :type: str
        """

        self._endpoint = endpoint

    @property
    def active(self):
        """Gets the active of this EventEndpointModel.  # noqa: E501

        Whether the Event Endpoint is active  # noqa: E501

        :return: The active of this EventEndpointModel.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this EventEndpointModel.

        Whether the Event Endpoint is active  # noqa: E501

        :param active: The active of this EventEndpointModel.  # noqa: E501
        :type: bool
        """

        self._active = active

    @property
    def creator_id(self):
        """Gets the creator_id of this EventEndpointModel.  # noqa: E501

        ID of the user that created the Event Endpoint.  # noqa: E501

        :return: The creator_id of this EventEndpointModel.  # noqa: E501
        :rtype: int
        """
        return self._creator_id

    @creator_id.setter
    def creator_id(self, creator_id):
        """Sets the creator_id of this EventEndpointModel.

        ID of the user that created the Event Endpoint.  # noqa: E501

        :param creator_id: The creator_id of this EventEndpointModel.  # noqa: E501
        :type: int
        """

        self._creator_id = creator_id

    @property
    def created_timestamp(self):
        """Gets the created_timestamp of this EventEndpointModel.  # noqa: E501

        The time the Event Endpoint was created.  # noqa: E501

        :return: The created_timestamp of this EventEndpointModel.  # noqa: E501
        :rtype: int
        """
        return self._created_timestamp

    @created_timestamp.setter
    def created_timestamp(self, created_timestamp):
        """Sets the created_timestamp of this EventEndpointModel.

        The time the Event Endpoint was created.  # noqa: E501

        :param created_timestamp: The created_timestamp of this EventEndpointModel.  # noqa: E501
        :type: int
        """

        self._created_timestamp = created_timestamp

    @property
    def auth_last_modified_user_id(self):
        """Gets the auth_last_modified_user_id of this EventEndpointModel.  # noqa: E501

        ID of the user that last modified authentication.  # noqa: E501

        :return: The auth_last_modified_user_id of this EventEndpointModel.  # noqa: E501
        :rtype: int
        """
        return self._auth_last_modified_user_id

    @auth_last_modified_user_id.setter
    def auth_last_modified_user_id(self, auth_last_modified_user_id):
        """Sets the auth_last_modified_user_id of this EventEndpointModel.

        ID of the user that last modified authentication.  # noqa: E501

        :param auth_last_modified_user_id: The auth_last_modified_user_id of this EventEndpointModel.  # noqa: E501
        :type: int
        """

        self._auth_last_modified_user_id = auth_last_modified_user_id

    @property
    def auth_last_modified_timestamp(self):
        """Gets the auth_last_modified_timestamp of this EventEndpointModel.  # noqa: E501

        The time authentication was last modified  # noqa: E501

        :return: The auth_last_modified_timestamp of this EventEndpointModel.  # noqa: E501
        :rtype: int
        """
        return self._auth_last_modified_timestamp

    @auth_last_modified_timestamp.setter
    def auth_last_modified_timestamp(self, auth_last_modified_timestamp):
        """Sets the auth_last_modified_timestamp of this EventEndpointModel.

        The time authentication was last modified  # noqa: E501

        :param auth_last_modified_timestamp: The auth_last_modified_timestamp of this EventEndpointModel.  # noqa: E501
        :type: int
        """

        self._auth_last_modified_timestamp = auth_last_modified_timestamp

    @property
    def auth_type(self):
        """Gets the auth_type of this EventEndpointModel.  # noqa: E501

        The authentication type for this Event Endpoint  # noqa: E501

        :return: The auth_type of this EventEndpointModel.  # noqa: E501
        :rtype: str
        """
        return self._auth_type

    @auth_type.setter
    def auth_type(self, auth_type):
        """Sets the auth_type of this EventEndpointModel.

        The authentication type for this Event Endpoint  # noqa: E501

        :param auth_type: The auth_type of this EventEndpointModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["NO_AUTH", "BASIC_AUTH", "X_HUB_SIGNATURE", "CUSTOM_HEADERS_ONLY"]  # noqa: E501
        if auth_type not in allowed_values:
            raise ValueError(
                "Invalid value for `auth_type` ({0}), must be one of {1}"  # noqa: E501
                .format(auth_type, allowed_values)
            )

        self._auth_type = auth_type

    @property
    def basic_auth_username(self):
        """Gets the basic_auth_username of this EventEndpointModel.  # noqa: E501

        The Username for when Basic Authentication is specified  # noqa: E501

        :return: The basic_auth_username of this EventEndpointModel.  # noqa: E501
        :rtype: str
        """
        return self._basic_auth_username

    @basic_auth_username.setter
    def basic_auth_username(self, basic_auth_username):
        """Sets the basic_auth_username of this EventEndpointModel.

        The Username for when Basic Authentication is specified  # noqa: E501

        :param basic_auth_username: The basic_auth_username of this EventEndpointModel.  # noqa: E501
        :type: str
        """

        self._basic_auth_username = basic_auth_username

    @property
    def basic_auth_password(self):
        """Gets the basic_auth_password of this EventEndpointModel.  # noqa: E501

        The Password for when Basic Authentication is specified  # noqa: E501

        :return: The basic_auth_password of this EventEndpointModel.  # noqa: E501
        :rtype: str
        """
        return self._basic_auth_password

    @basic_auth_password.setter
    def basic_auth_password(self, basic_auth_password):
        """Sets the basic_auth_password of this EventEndpointModel.

        The Password for when Basic Authentication is specified  # noqa: E501

        :param basic_auth_password: The basic_auth_password of this EventEndpointModel.  # noqa: E501
        :type: str
        """

        self._basic_auth_password = basic_auth_password

    @property
    def x_hub_signature_secret(self):
        """Gets the x_hub_signature_secret of this EventEndpointModel.  # noqa: E501

        The Secret Key for when X-Hub-Signature is specified  # noqa: E501

        :return: The x_hub_signature_secret of this EventEndpointModel.  # noqa: E501
        :rtype: str
        """
        return self._x_hub_signature_secret

    @x_hub_signature_secret.setter
    def x_hub_signature_secret(self, x_hub_signature_secret):
        """Sets the x_hub_signature_secret of this EventEndpointModel.

        The Secret Key for when X-Hub-Signature is specified  # noqa: E501

        :param x_hub_signature_secret: The x_hub_signature_secret of this EventEndpointModel.  # noqa: E501
        :type: str
        """

        self._x_hub_signature_secret = x_hub_signature_secret

    @property
    def x_hub_signature_data(self):
        """Gets the x_hub_signature_data of this EventEndpointModel.  # noqa: E501

        It's the secret code shared between you and Chatbox when X-Hub-Signature authentication is specified that allows you to verify that API traffic sent to an Automation by Chatbox is genuine.  # noqa: E501

        :return: The x_hub_signature_data of this EventEndpointModel.  # noqa: E501
        :rtype: str
        """
        return self._x_hub_signature_data

    @x_hub_signature_data.setter
    def x_hub_signature_data(self, x_hub_signature_data):
        """Sets the x_hub_signature_data of this EventEndpointModel.

        It's the secret code shared between you and Chatbox when X-Hub-Signature authentication is specified that allows you to verify that API traffic sent to an Automation by Chatbox is genuine.  # noqa: E501

        :param x_hub_signature_data: The x_hub_signature_data of this EventEndpointModel.  # noqa: E501
        :type: str
        """

        self._x_hub_signature_data = x_hub_signature_data

    @property
    def events(self):
        """Gets the events of this EventEndpointModel.  # noqa: E501

        The endpoint will be called when any of these events occur.  # noqa: E501

        :return: The events of this EventEndpointModel.  # noqa: E501
        :rtype: list[str]
        """
        return self._events

    @events.setter
    def events(self, events):
        """Sets the events of this EventEndpointModel.

        The endpoint will be called when any of these events occur.  # noqa: E501

        :param events: The events of this EventEndpointModel.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["CUSTOMER_ADDED", "MESSAGE_ADDED", "MESSAGE_STATUS", "CONVERSATION_ADDED", "CONVERSATION_JOINED", "CONVERSATION_LEFT", "INSTANT_APP_ADDED", "INSTANT_APP_CUSTOMER_CONNECTED", "INSTANT_APP_CUSTOMER_DISCONNECTED", "INSTANT_APP_STATUS", "INSTANT_APP_UPDATE", "INSTANT_APP_CUSTOM", "BULK_ACTION", "CARRIER_REJECTION_RATE_EXCEEDED", "LOGIN", "LOGOUT", "AGENT_TOOLS_START", "AGENT_TOOLS_END", "AGENT_TOOLS_IDLE", "AGENT_TOOLS_BOOTED", "MONITOR_START", "MONITOR_END", "MONITOR_INSPECT", "MESSAGE_SCHEDULED", "SCHEDULED_MESSAGE_DELETED", "SCHEDULED_MESSAGE_MODIFIED", "CHANNEL_ADDED", "CHANNEL_DELETED", "CHANNEL_MODIFIED", "AGENT_ADDED", "AGENT_DELETED", "AGENT_MODIFIED", "SEND_MESSAGE_ERROR", "ALTERRA_ERROR", "INSTANT_APP_SCRIPT_ERROR", "CUSTOMER_CHANNEL_MODIFIED", "CUSTOMER_MODIFIED", "CUSTOMER_OPT_OUT", "NOTIFICATION_SENT", "NOTIFICATION_MODIFIED", "INTERACTION_CONFIG_MODIFIED", "GOOGLE_SHEETS_READ", "GOOGLE_SHEETS_WRITE", "CONSOLE_LOG_INFO", "CONSOLE_LOG_WARN", "CONSOLE_LOG_ERROR", "CONTACT_LIST_IMPORT_STARTED", "CONTACT_LIST_IMPORT_COMPLETED"]  # noqa: E501
        if not set(events).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `events` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(events) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._events = events

    @property
    def custom_headers(self):
        """Gets the custom_headers of this EventEndpointModel.  # noqa: E501

        Custom headers that can be additionally supplied to authenticated event endpoint calls.  # noqa: E501

        :return: The custom_headers of this EventEndpointModel.  # noqa: E501
        :rtype: list[KeyValueDataModel]
        """
        return self._custom_headers

    @custom_headers.setter
    def custom_headers(self, custom_headers):
        """Sets the custom_headers of this EventEndpointModel.

        Custom headers that can be additionally supplied to authenticated event endpoint calls.  # noqa: E501

        :param custom_headers: The custom_headers of this EventEndpointModel.  # noqa: E501
        :type: list[KeyValueDataModel]
        """

        self._custom_headers = custom_headers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EventEndpointModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EventEndpointModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SalesforceIntegrationRequestModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'salesforce_login': 'str',
        'salesforce_password': 'str',
        'environment': 'str'
    }

    attribute_map = {
        'salesforce_login': 'salesforceLogin',
        'salesforce_password': 'salesforcePassword',
        'environment': 'environment'
    }

    def __init__(self, salesforce_login=None, salesforce_password=None, environment=None):  # noqa: E501
        """SalesforceIntegrationRequestModel - a model defined in Swagger"""  # noqa: E501
        self._salesforce_login = None
        self._salesforce_password = None
        self._environment = None
        self.discriminator = None
        if salesforce_login is not None:
            self.salesforce_login = salesforce_login
        if salesforce_password is not None:
            self.salesforce_password = salesforce_password
        if environment is not None:
            self.environment = environment

    @property
    def salesforce_login(self):
        """Gets the salesforce_login of this SalesforceIntegrationRequestModel.  # noqa: E501

        Salesforce login  # noqa: E501

        :return: The salesforce_login of this SalesforceIntegrationRequestModel.  # noqa: E501
        :rtype: str
        """
        return self._salesforce_login

    @salesforce_login.setter
    def salesforce_login(self, salesforce_login):
        """Sets the salesforce_login of this SalesforceIntegrationRequestModel.

        Salesforce login  # noqa: E501

        :param salesforce_login: The salesforce_login of this SalesforceIntegrationRequestModel.  # noqa: E501
        :type: str
        """

        self._salesforce_login = salesforce_login

    @property
    def salesforce_password(self):
        """Gets the salesforce_password of this SalesforceIntegrationRequestModel.  # noqa: E501

        Salesforce password combined with the security token. example: MyPasswordMyToken  # noqa: E501

        :return: The salesforce_password of this SalesforceIntegrationRequestModel.  # noqa: E501
        :rtype: str
        """
        return self._salesforce_password

    @salesforce_password.setter
    def salesforce_password(self, salesforce_password):
        """Sets the salesforce_password of this SalesforceIntegrationRequestModel.

        Salesforce password combined with the security token. example: MyPasswordMyToken  # noqa: E501

        :param salesforce_password: The salesforce_password of this SalesforceIntegrationRequestModel.  # noqa: E501
        :type: str
        """

        self._salesforce_password = salesforce_password

    @property
    def environment(self):
        """Gets the environment of this SalesforceIntegrationRequestModel.  # noqa: E501

        Salesforce environment: prod/test. default is 'prod'  # noqa: E501

        :return: The environment of this SalesforceIntegrationRequestModel.  # noqa: E501
        :rtype: str
        """
        return self._environment

    @environment.setter
    def environment(self, environment):
        """Sets the environment of this SalesforceIntegrationRequestModel.

        Salesforce environment: prod/test. default is 'prod'  # noqa: E501

        :param environment: The environment of this SalesforceIntegrationRequestModel.  # noqa: E501
        :type: str
        """

        self._environment = environment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SalesforceIntegrationRequestModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SalesforceIntegrationRequestModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.customers_api import CustomersApi  # noqa: E501
from swagger_client.rest import ApiException


class TestCustomersApi(unittest.TestCase):
    """CustomersApi unit test stubs"""

    def setUp(self):
        self.api = CustomersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_customer(self):
        """Test case for add_customer

        Creates a customer  # noqa: E501
        """
        pass

    def test_add_customer_tags(self):
        """Test case for add_customer_tags

        Adds tags to a customer  # noqa: E501
        """
        pass

    def test_add_identity(self):
        """Test case for add_identity

        Adds an identity to a customer  # noqa: E501
        """
        pass

    def test_add_or_update_customer(self):
        """Test case for add_or_update_customer

        Creates or updates a customer  # noqa: E501
        """
        pass

    def test_create_instant_app(self):
        """Test case for create_instant_app

        Creates an Instant App for the customer.  # noqa: E501
        """
        pass

    def test_delete_identity(self):
        """Test case for delete_identity

        Deletes an identity from a customer  # noqa: E501
        """
        pass

    def test_get_customer(self):
        """Test case for get_customer

        Gets the details for a specific customer  # noqa: E501
        """
        pass

    def test_get_customer_by_channel(self):
        """Test case for get_customer_by_channel

        Gets the details for a specific customer based on an the channel type and channel key  # noqa: E501
        """
        pass

    def test_get_customer_by_identity(self):
        """Test case for get_customer_by_identity

        Gets the details for a specific customer based on an identity  # noqa: E501
        """
        pass

    def test_get_customer_tags(self):
        """Test case for get_customer_tags

        Gets the tags for a specific customer  # noqa: E501
        """
        pass

    def test_get_customers(self):
        """Test case for get_customers

        Gets all the customers in the org ordered by their create date  # noqa: E501
        """
        pass

    def test_get_instant_apps(self):
        """Test case for get_instant_apps

        Gets all the Instant Apps for the customer  # noqa: E501
        """
        pass

    def test_remove_tag(self):
        """Test case for remove_tag

        Removes a tag from a customer  # noqa: E501
        """
        pass

    def test_remove_tags(self):
        """Test case for remove_tags

        Removes all tags from a customer  # noqa: E501
        """
        pass

    def test_update_customer(self):
        """Test case for update_customer

        Updates a customer  # noqa: E501
        """
        pass

    def test_update_customer_location(self):
        """Test case for update_customer_location

        Updates a customers location  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class OrgChannelModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'name': 'str',
        'api_id': 'str',
        'channel_type': 'str',
        'active': 'bool',
        'channel_key': 'str',
        'first_message': 'str',
        'first_message_enabled': 'bool',
        'api_opt_out_message': 'str',
        'api_opt_out_message_enabled': 'bool',
        'opt_out_final_message': 'str',
        'opt_out_final_message_enabled': 'bool',
        'incoming_call_response_type': 'str',
        'incoming_call_audio_upload_id': 'int',
        'incoming_call_forward_number': 'str',
        'unsupported_media_message': 'str',
        'facebook_model': 'FacebookOrgChannelModel',
        'sms_model': 'SMSOrgChannelModel',
        'twilio_model': 'TwilioOrgChannelModel',
        'ytel_model': 'YtelOrgChannelModel',
        'smooch_model': 'SmoochChatOrgChannelModel',
        'line_model': 'LineOrgChannelModel',
        'zipwhip_model': 'ZipwhipOrgChannelModel',
        'bandwidth_model': 'BandwidthOrgChannelModel',
        'managed_bandwidth_model': 'ManagedBandwidthOrgChannelModel',
        'pre_purchased': 'bool',
        'channel_apps': 'list[str]'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'api_id': 'apiId',
        'channel_type': 'channelType',
        'active': 'active',
        'channel_key': 'channelKey',
        'first_message': 'firstMessage',
        'first_message_enabled': 'firstMessageEnabled',
        'api_opt_out_message': 'apiOptOutMessage',
        'api_opt_out_message_enabled': 'apiOptOutMessageEnabled',
        'opt_out_final_message': 'optOutFinalMessage',
        'opt_out_final_message_enabled': 'optOutFinalMessageEnabled',
        'incoming_call_response_type': 'incomingCallResponseType',
        'incoming_call_audio_upload_id': 'incomingCallAudioUploadId',
        'incoming_call_forward_number': 'incomingCallForwardNumber',
        'unsupported_media_message': 'unsupportedMediaMessage',
        'facebook_model': 'facebookModel',
        'sms_model': 'smsModel',
        'twilio_model': 'twilioModel',
        'ytel_model': 'ytelModel',
        'smooch_model': 'smoochModel',
        'line_model': 'lineModel',
        'zipwhip_model': 'zipwhipModel',
        'bandwidth_model': 'bandwidthModel',
        'managed_bandwidth_model': 'managedBandwidthModel',
        'pre_purchased': 'prePurchased',
        'channel_apps': 'channelApps'
    }

    def __init__(self, id=None, name=None, api_id=None, channel_type=None, active=None, channel_key=None, first_message=None, first_message_enabled=None, api_opt_out_message=None, api_opt_out_message_enabled=None, opt_out_final_message=None, opt_out_final_message_enabled=None, incoming_call_response_type=None, incoming_call_audio_upload_id=None, incoming_call_forward_number=None, unsupported_media_message=None, facebook_model=None, sms_model=None, twilio_model=None, ytel_model=None, smooch_model=None, line_model=None, zipwhip_model=None, bandwidth_model=None, managed_bandwidth_model=None, pre_purchased=None, channel_apps=None):  # noqa: E501
        """OrgChannelModel - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._api_id = None
        self._channel_type = None
        self._active = None
        self._channel_key = None
        self._first_message = None
        self._first_message_enabled = None
        self._api_opt_out_message = None
        self._api_opt_out_message_enabled = None
        self._opt_out_final_message = None
        self._opt_out_final_message_enabled = None
        self._incoming_call_response_type = None
        self._incoming_call_audio_upload_id = None
        self._incoming_call_forward_number = None
        self._unsupported_media_message = None
        self._facebook_model = None
        self._sms_model = None
        self._twilio_model = None
        self._ytel_model = None
        self._smooch_model = None
        self._line_model = None
        self._zipwhip_model = None
        self._bandwidth_model = None
        self._managed_bandwidth_model = None
        self._pre_purchased = None
        self._channel_apps = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if api_id is not None:
            self.api_id = api_id
        if channel_type is not None:
            self.channel_type = channel_type
        if active is not None:
            self.active = active
        if channel_key is not None:
            self.channel_key = channel_key
        if first_message is not None:
            self.first_message = first_message
        if first_message_enabled is not None:
            self.first_message_enabled = first_message_enabled
        if api_opt_out_message is not None:
            self.api_opt_out_message = api_opt_out_message
        if api_opt_out_message_enabled is not None:
            self.api_opt_out_message_enabled = api_opt_out_message_enabled
        if opt_out_final_message is not None:
            self.opt_out_final_message = opt_out_final_message
        if opt_out_final_message_enabled is not None:
            self.opt_out_final_message_enabled = opt_out_final_message_enabled
        if incoming_call_response_type is not None:
            self.incoming_call_response_type = incoming_call_response_type
        if incoming_call_audio_upload_id is not None:
            self.incoming_call_audio_upload_id = incoming_call_audio_upload_id
        if incoming_call_forward_number is not None:
            self.incoming_call_forward_number = incoming_call_forward_number
        if unsupported_media_message is not None:
            self.unsupported_media_message = unsupported_media_message
        if facebook_model is not None:
            self.facebook_model = facebook_model
        if sms_model is not None:
            self.sms_model = sms_model
        if twilio_model is not None:
            self.twilio_model = twilio_model
        if ytel_model is not None:
            self.ytel_model = ytel_model
        if smooch_model is not None:
            self.smooch_model = smooch_model
        if line_model is not None:
            self.line_model = line_model
        if zipwhip_model is not None:
            self.zipwhip_model = zipwhip_model
        if bandwidth_model is not None:
            self.bandwidth_model = bandwidth_model
        if managed_bandwidth_model is not None:
            self.managed_bandwidth_model = managed_bandwidth_model
        if pre_purchased is not None:
            self.pre_purchased = pre_purchased
        if channel_apps is not None:
            self.channel_apps = channel_apps

    @property
    def id(self):
        """Gets the id of this OrgChannelModel.  # noqa: E501

        The system generated unique id for this channel.  # noqa: E501

        :return: The id of this OrgChannelModel.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OrgChannelModel.

        The system generated unique id for this channel.  # noqa: E501

        :param id: The id of this OrgChannelModel.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this OrgChannelModel.  # noqa: E501

        A descriptive name for this channel to show in agent UIs.  # noqa: E501

        :return: The name of this OrgChannelModel.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this OrgChannelModel.

        A descriptive name for this channel to show in agent UIs.  # noqa: E501

        :param name: The name of this OrgChannelModel.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def api_id(self):
        """Gets the api_id of this OrgChannelModel.  # noqa: E501

        The programmatic, unique id of this channel.  # noqa: E501

        :return: The api_id of this OrgChannelModel.  # noqa: E501
        :rtype: str
        """
        return self._api_id

    @api_id.setter
    def api_id(self, api_id):
        """Sets the api_id of this OrgChannelModel.

        The programmatic, unique id of this channel.  # noqa: E501

        :param api_id: The api_id of this OrgChannelModel.  # noqa: E501
        :type: str
        """

        self._api_id = api_id

    @property
    def channel_type(self):
        """Gets the channel_type of this OrgChannelModel.  # noqa: E501

        The type of outgoing communication channel  # noqa: E501

        :return: The channel_type of this OrgChannelModel.  # noqa: E501
        :rtype: str
        """
        return self._channel_type

    @channel_type.setter
    def channel_type(self, channel_type):
        """Sets the channel_type of this OrgChannelModel.

        The type of outgoing communication channel  # noqa: E501

        :param channel_type: The channel_type of this OrgChannelModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["SMS", "FACEBOOK", "TWILIO", "LINE", "ZIPWHIP", "SMOOCH_CHAT", "YTEL", "INTERNAL", "BANDWIDTH", "POOL", "MANAGED_BANDWIDTH", "MANAGED_SIGNAL_WIRE", "SIGNAL_WIRE"]  # noqa: E501
        if channel_type not in allowed_values:
            raise ValueError(
                "Invalid value for `channel_type` ({0}), must be one of {1}"  # noqa: E501
                .format(channel_type, allowed_values)
            )

        self._channel_type = channel_type

    @property
    def active(self):
        """Gets the active of this OrgChannelModel.  # noqa: E501

        The active status of the channel  # noqa: E501

        :return: The active of this OrgChannelModel.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this OrgChannelModel.

        The active status of the channel  # noqa: E501

        :param active: The active of this OrgChannelModel.  # noqa: E501
        :type: bool
        """

        self._active = active

    @property
    def channel_key(self):
        """Gets the channel_key of this OrgChannelModel.  # noqa: E501

        The unique key value for this channel.Maps to, and can only be changed from a channel type specific property.  # noqa: E501

        :return: The channel_key of this OrgChannelModel.  # noqa: E501
        :rtype: str
        """
        return self._channel_key

    @channel_key.setter
    def channel_key(self, channel_key):
        """Sets the channel_key of this OrgChannelModel.

        The unique key value for this channel.Maps to, and can only be changed from a channel type specific property.  # noqa: E501

        :param channel_key: The channel_key of this OrgChannelModel.  # noqa: E501
        :type: str
        """

        self._channel_key = channel_key

    @property
    def first_message(self):
        """Gets the first_message of this OrgChannelModel.  # noqa: E501

        Customers on this channel will always receive the supplied message before any other messages are sent to them.  # noqa: E501

        :return: The first_message of this OrgChannelModel.  # noqa: E501
        :rtype: str
        """
        return self._first_message

    @first_message.setter
    def first_message(self, first_message):
        """Sets the first_message of this OrgChannelModel.

        Customers on this channel will always receive the supplied message before any other messages are sent to them.  # noqa: E501

        :param first_message: The first_message of this OrgChannelModel.  # noqa: E501
        :type: str
        """

        self._first_message = first_message

    @property
    def first_message_enabled(self):
        """Gets the first_message_enabled of this OrgChannelModel.  # noqa: E501

        Enable / disable first message functionality  # noqa: E501

        :return: The first_message_enabled of this OrgChannelModel.  # noqa: E501
        :rtype: bool
        """
        return self._first_message_enabled

    @first_message_enabled.setter
    def first_message_enabled(self, first_message_enabled):
        """Sets the first_message_enabled of this OrgChannelModel.

        Enable / disable first message functionality  # noqa: E501

        :param first_message_enabled: The first_message_enabled of this OrgChannelModel.  # noqa: E501
        :type: bool
        """

        self._first_message_enabled = first_message_enabled

    @property
    def api_opt_out_message(self):
        """Gets the api_opt_out_message of this OrgChannelModel.  # noqa: E501

        Customers will receive this message if they are API opted out of this channel but not phone provider opted out.  # noqa: E501

        :return: The api_opt_out_message of this OrgChannelModel.  # noqa: E501
        :rtype: str
        """
        return self._api_opt_out_message

    @api_opt_out_message.setter
    def api_opt_out_message(self, api_opt_out_message):
        """Sets the api_opt_out_message of this OrgChannelModel.

        Customers will receive this message if they are API opted out of this channel but not phone provider opted out.  # noqa: E501

        :param api_opt_out_message: The api_opt_out_message of this OrgChannelModel.  # noqa: E501
        :type: str
        """

        self._api_opt_out_message = api_opt_out_message

    @property
    def api_opt_out_message_enabled(self):
        """Gets the api_opt_out_message_enabled of this OrgChannelModel.  # noqa: E501

        Enable / disable API opt out message  # noqa: E501

        :return: The api_opt_out_message_enabled of this OrgChannelModel.  # noqa: E501
        :rtype: bool
        """
        return self._api_opt_out_message_enabled

    @api_opt_out_message_enabled.setter
    def api_opt_out_message_enabled(self, api_opt_out_message_enabled):
        """Sets the api_opt_out_message_enabled of this OrgChannelModel.

        Enable / disable API opt out message  # noqa: E501

        :param api_opt_out_message_enabled: The api_opt_out_message_enabled of this OrgChannelModel.  # noqa: E501
        :type: bool
        """

        self._api_opt_out_message_enabled = api_opt_out_message_enabled

    @property
    def opt_out_final_message(self):
        """Gets the opt_out_final_message of this OrgChannelModel.  # noqa: E501

        Customers will receive this message when they opt out of this channel (short code only)  # noqa: E501

        :return: The opt_out_final_message of this OrgChannelModel.  # noqa: E501
        :rtype: str
        """
        return self._opt_out_final_message

    @opt_out_final_message.setter
    def opt_out_final_message(self, opt_out_final_message):
        """Sets the opt_out_final_message of this OrgChannelModel.

        Customers will receive this message when they opt out of this channel (short code only)  # noqa: E501

        :param opt_out_final_message: The opt_out_final_message of this OrgChannelModel.  # noqa: E501
        :type: str
        """

        self._opt_out_final_message = opt_out_final_message

    @property
    def opt_out_final_message_enabled(self):
        """Gets the opt_out_final_message_enabled of this OrgChannelModel.  # noqa: E501

        Enable / disable opt out final message (short code only)  # noqa: E501

        :return: The opt_out_final_message_enabled of this OrgChannelModel.  # noqa: E501
        :rtype: bool
        """
        return self._opt_out_final_message_enabled

    @opt_out_final_message_enabled.setter
    def opt_out_final_message_enabled(self, opt_out_final_message_enabled):
        """Sets the opt_out_final_message_enabled of this OrgChannelModel.

        Enable / disable opt out final message (short code only)  # noqa: E501

        :param opt_out_final_message_enabled: The opt_out_final_message_enabled of this OrgChannelModel.  # noqa: E501
        :type: bool
        """

        self._opt_out_final_message_enabled = opt_out_final_message_enabled

    @property
    def incoming_call_response_type(self):
        """Gets the incoming_call_response_type of this OrgChannelModel.  # noqa: E501

        Type of response when receiving an incoming call on this channel  # noqa: E501

        :return: The incoming_call_response_type of this OrgChannelModel.  # noqa: E501
        :rtype: str
        """
        return self._incoming_call_response_type

    @incoming_call_response_type.setter
    def incoming_call_response_type(self, incoming_call_response_type):
        """Sets the incoming_call_response_type of this OrgChannelModel.

        Type of response when receiving an incoming call on this channel  # noqa: E501

        :param incoming_call_response_type: The incoming_call_response_type of this OrgChannelModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["FORWARD", "PLAY_AUDIO", "REJECT"]  # noqa: E501
        if incoming_call_response_type not in allowed_values:
            raise ValueError(
                "Invalid value for `incoming_call_response_type` ({0}), must be one of {1}"  # noqa: E501
                .format(incoming_call_response_type, allowed_values)
            )

        self._incoming_call_response_type = incoming_call_response_type

    @property
    def incoming_call_audio_upload_id(self):
        """Gets the incoming_call_audio_upload_id of this OrgChannelModel.  # noqa: E501

        Audio file to be played to an incoming call when PLAY_AUDIO response type is selected  # noqa: E501

        :return: The incoming_call_audio_upload_id of this OrgChannelModel.  # noqa: E501
        :rtype: int
        """
        return self._incoming_call_audio_upload_id

    @incoming_call_audio_upload_id.setter
    def incoming_call_audio_upload_id(self, incoming_call_audio_upload_id):
        """Sets the incoming_call_audio_upload_id of this OrgChannelModel.

        Audio file to be played to an incoming call when PLAY_AUDIO response type is selected  # noqa: E501

        :param incoming_call_audio_upload_id: The incoming_call_audio_upload_id of this OrgChannelModel.  # noqa: E501
        :type: int
        """

        self._incoming_call_audio_upload_id = incoming_call_audio_upload_id

    @property
    def incoming_call_forward_number(self):
        """Gets the incoming_call_forward_number of this OrgChannelModel.  # noqa: E501

        Number for an incoming call to be forwarded to when FORWARD response type is selected  # noqa: E501

        :return: The incoming_call_forward_number of this OrgChannelModel.  # noqa: E501
        :rtype: str
        """
        return self._incoming_call_forward_number

    @incoming_call_forward_number.setter
    def incoming_call_forward_number(self, incoming_call_forward_number):
        """Sets the incoming_call_forward_number of this OrgChannelModel.

        Number for an incoming call to be forwarded to when FORWARD response type is selected  # noqa: E501

        :param incoming_call_forward_number: The incoming_call_forward_number of this OrgChannelModel.  # noqa: E501
        :type: str
        """

        self._incoming_call_forward_number = incoming_call_forward_number

    @property
    def unsupported_media_message(self):
        """Gets the unsupported_media_message of this OrgChannelModel.  # noqa: E501

        Alternative message to send when attempting to send a media file that is not supported by the carrier  # noqa: E501

        :return: The unsupported_media_message of this OrgChannelModel.  # noqa: E501
        :rtype: str
        """
        return self._unsupported_media_message

    @unsupported_media_message.setter
    def unsupported_media_message(self, unsupported_media_message):
        """Sets the unsupported_media_message of this OrgChannelModel.

        Alternative message to send when attempting to send a media file that is not supported by the carrier  # noqa: E501

        :param unsupported_media_message: The unsupported_media_message of this OrgChannelModel.  # noqa: E501
        :type: str
        """

        self._unsupported_media_message = unsupported_media_message

    @property
    def facebook_model(self):
        """Gets the facebook_model of this OrgChannelModel.  # noqa: E501


        :return: The facebook_model of this OrgChannelModel.  # noqa: E501
        :rtype: FacebookOrgChannelModel
        """
        return self._facebook_model

    @facebook_model.setter
    def facebook_model(self, facebook_model):
        """Sets the facebook_model of this OrgChannelModel.


        :param facebook_model: The facebook_model of this OrgChannelModel.  # noqa: E501
        :type: FacebookOrgChannelModel
        """

        self._facebook_model = facebook_model

    @property
    def sms_model(self):
        """Gets the sms_model of this OrgChannelModel.  # noqa: E501


        :return: The sms_model of this OrgChannelModel.  # noqa: E501
        :rtype: SMSOrgChannelModel
        """
        return self._sms_model

    @sms_model.setter
    def sms_model(self, sms_model):
        """Sets the sms_model of this OrgChannelModel.


        :param sms_model: The sms_model of this OrgChannelModel.  # noqa: E501
        :type: SMSOrgChannelModel
        """

        self._sms_model = sms_model

    @property
    def twilio_model(self):
        """Gets the twilio_model of this OrgChannelModel.  # noqa: E501


        :return: The twilio_model of this OrgChannelModel.  # noqa: E501
        :rtype: TwilioOrgChannelModel
        """
        return self._twilio_model

    @twilio_model.setter
    def twilio_model(self, twilio_model):
        """Sets the twilio_model of this OrgChannelModel.


        :param twilio_model: The twilio_model of this OrgChannelModel.  # noqa: E501
        :type: TwilioOrgChannelModel
        """

        self._twilio_model = twilio_model

    @property
    def ytel_model(self):
        """Gets the ytel_model of this OrgChannelModel.  # noqa: E501


        :return: The ytel_model of this OrgChannelModel.  # noqa: E501
        :rtype: YtelOrgChannelModel
        """
        return self._ytel_model

    @ytel_model.setter
    def ytel_model(self, ytel_model):
        """Sets the ytel_model of this OrgChannelModel.


        :param ytel_model: The ytel_model of this OrgChannelModel.  # noqa: E501
        :type: YtelOrgChannelModel
        """

        self._ytel_model = ytel_model

    @property
    def smooch_model(self):
        """Gets the smooch_model of this OrgChannelModel.  # noqa: E501


        :return: The smooch_model of this OrgChannelModel.  # noqa: E501
        :rtype: SmoochChatOrgChannelModel
        """
        return self._smooch_model

    @smooch_model.setter
    def smooch_model(self, smooch_model):
        """Sets the smooch_model of this OrgChannelModel.


        :param smooch_model: The smooch_model of this OrgChannelModel.  # noqa: E501
        :type: SmoochChatOrgChannelModel
        """

        self._smooch_model = smooch_model

    @property
    def line_model(self):
        """Gets the line_model of this OrgChannelModel.  # noqa: E501


        :return: The line_model of this OrgChannelModel.  # noqa: E501
        :rtype: LineOrgChannelModel
        """
        return self._line_model

    @line_model.setter
    def line_model(self, line_model):
        """Sets the line_model of this OrgChannelModel.


        :param line_model: The line_model of this OrgChannelModel.  # noqa: E501
        :type: LineOrgChannelModel
        """

        self._line_model = line_model

    @property
    def zipwhip_model(self):
        """Gets the zipwhip_model of this OrgChannelModel.  # noqa: E501


        :return: The zipwhip_model of this OrgChannelModel.  # noqa: E501
        :rtype: ZipwhipOrgChannelModel
        """
        return self._zipwhip_model

    @zipwhip_model.setter
    def zipwhip_model(self, zipwhip_model):
        """Sets the zipwhip_model of this OrgChannelModel.


        :param zipwhip_model: The zipwhip_model of this OrgChannelModel.  # noqa: E501
        :type: ZipwhipOrgChannelModel
        """

        self._zipwhip_model = zipwhip_model

    @property
    def bandwidth_model(self):
        """Gets the bandwidth_model of this OrgChannelModel.  # noqa: E501


        :return: The bandwidth_model of this OrgChannelModel.  # noqa: E501
        :rtype: BandwidthOrgChannelModel
        """
        return self._bandwidth_model

    @bandwidth_model.setter
    def bandwidth_model(self, bandwidth_model):
        """Sets the bandwidth_model of this OrgChannelModel.


        :param bandwidth_model: The bandwidth_model of this OrgChannelModel.  # noqa: E501
        :type: BandwidthOrgChannelModel
        """

        self._bandwidth_model = bandwidth_model

    @property
    def managed_bandwidth_model(self):
        """Gets the managed_bandwidth_model of this OrgChannelModel.  # noqa: E501


        :return: The managed_bandwidth_model of this OrgChannelModel.  # noqa: E501
        :rtype: ManagedBandwidthOrgChannelModel
        """
        return self._managed_bandwidth_model

    @managed_bandwidth_model.setter
    def managed_bandwidth_model(self, managed_bandwidth_model):
        """Sets the managed_bandwidth_model of this OrgChannelModel.


        :param managed_bandwidth_model: The managed_bandwidth_model of this OrgChannelModel.  # noqa: E501
        :type: ManagedBandwidthOrgChannelModel
        """

        self._managed_bandwidth_model = managed_bandwidth_model

    @property
    def pre_purchased(self):
        """Gets the pre_purchased of this OrgChannelModel.  # noqa: E501

        Specifies whether the channel has already been purchased  # noqa: E501

        :return: The pre_purchased of this OrgChannelModel.  # noqa: E501
        :rtype: bool
        """
        return self._pre_purchased

    @pre_purchased.setter
    def pre_purchased(self, pre_purchased):
        """Sets the pre_purchased of this OrgChannelModel.

        Specifies whether the channel has already been purchased  # noqa: E501

        :param pre_purchased: The pre_purchased of this OrgChannelModel.  # noqa: E501
        :type: bool
        """

        self._pre_purchased = pre_purchased

    @property
    def channel_apps(self):
        """Gets the channel_apps of this OrgChannelModel.  # noqa: E501


        :return: The channel_apps of this OrgChannelModel.  # noqa: E501
        :rtype: list[str]
        """
        return self._channel_apps

    @channel_apps.setter
    def channel_apps(self, channel_apps):
        """Sets the channel_apps of this OrgChannelModel.


        :param channel_apps: The channel_apps of this OrgChannelModel.  # noqa: E501
        :type: list[str]
        """

        self._channel_apps = channel_apps

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OrgChannelModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrgChannelModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AddBulkActionModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'org_channel_ids': 'list[str]',
        'contact_lists': 'list[str]',
        'message': 'str',
        'whisper': 'str',
        'variants': 'list[AddBulkActionVariantModel]',
        'retarget': 'BulkActionRetargetModel',
        'instant_app_schema_id': 'str',
        'instant_app_message': 'str',
        'instant_app_parameters': 'str',
        'instant_app_locale': 'str',
        'delivery_start': 'int',
        'snippet_code': 'str',
        'on_error_snippet_code': 'str',
        'upload_id': 'int',
        'complete_conversation': 'bool',
        'escalate_to_agent': 'bool',
        'escalate_groups': 'list[int]',
        'call_event_endpoint': 'bool',
        'event_endpoint_path': 'str',
        'assign_to_bot': 'int',
        'is_manual': 'bool',
        'delivery_window_start': 'int',
        'delivery_window_end': 'int',
        'use_existing_channels': 'bool',
        'match_area_codes': 'bool',
        'minimum_channels': 'int',
        'is_test_mode': 'bool',
        'description': 'str',
        'is_paused': 'bool',
        'primary_folder_id': 'int'
    }

    attribute_map = {
        'org_channel_ids': 'orgChannelIds',
        'contact_lists': 'contactLists',
        'message': 'message',
        'whisper': 'whisper',
        'variants': 'variants',
        'retarget': 'retarget',
        'instant_app_schema_id': 'instantAppSchemaID',
        'instant_app_message': 'instantAppMessage',
        'instant_app_parameters': 'instantAppParameters',
        'instant_app_locale': 'instantAppLocale',
        'delivery_start': 'deliveryStart',
        'snippet_code': 'snippetCode',
        'on_error_snippet_code': 'onErrorSnippetCode',
        'upload_id': 'uploadId',
        'complete_conversation': 'completeConversation',
        'escalate_to_agent': 'escalateToAgent',
        'escalate_groups': 'escalateGroups',
        'call_event_endpoint': 'callEventEndpoint',
        'event_endpoint_path': 'eventEndpointPath',
        'assign_to_bot': 'assignToBot',
        'is_manual': 'isManual',
        'delivery_window_start': 'deliveryWindowStart',
        'delivery_window_end': 'deliveryWindowEnd',
        'use_existing_channels': 'useExistingChannels',
        'match_area_codes': 'matchAreaCodes',
        'minimum_channels': 'minimumChannels',
        'is_test_mode': 'isTestMode',
        'description': 'description',
        'is_paused': 'isPaused',
        'primary_folder_id': 'primaryFolderId'
    }

    def __init__(self, org_channel_ids=None, contact_lists=None, message=None, whisper=None, variants=None, retarget=None, instant_app_schema_id=None, instant_app_message=None, instant_app_parameters=None, instant_app_locale=None, delivery_start=None, snippet_code=None, on_error_snippet_code=None, upload_id=None, complete_conversation=None, escalate_to_agent=None, escalate_groups=None, call_event_endpoint=None, event_endpoint_path=None, assign_to_bot=None, is_manual=None, delivery_window_start=None, delivery_window_end=None, use_existing_channels=None, match_area_codes=None, minimum_channels=None, is_test_mode=None, description=None, is_paused=None, primary_folder_id=None):  # noqa: E501
        """AddBulkActionModel - a model defined in Swagger"""  # noqa: E501
        self._org_channel_ids = None
        self._contact_lists = None
        self._message = None
        self._whisper = None
        self._variants = None
        self._retarget = None
        self._instant_app_schema_id = None
        self._instant_app_message = None
        self._instant_app_parameters = None
        self._instant_app_locale = None
        self._delivery_start = None
        self._snippet_code = None
        self._on_error_snippet_code = None
        self._upload_id = None
        self._complete_conversation = None
        self._escalate_to_agent = None
        self._escalate_groups = None
        self._call_event_endpoint = None
        self._event_endpoint_path = None
        self._assign_to_bot = None
        self._is_manual = None
        self._delivery_window_start = None
        self._delivery_window_end = None
        self._use_existing_channels = None
        self._match_area_codes = None
        self._minimum_channels = None
        self._is_test_mode = None
        self._description = None
        self._is_paused = None
        self._primary_folder_id = None
        self.discriminator = None
        self.org_channel_ids = org_channel_ids
        self.contact_lists = contact_lists
        if message is not None:
            self.message = message
        if whisper is not None:
            self.whisper = whisper
        if variants is not None:
            self.variants = variants
        if retarget is not None:
            self.retarget = retarget
        if instant_app_schema_id is not None:
            self.instant_app_schema_id = instant_app_schema_id
        if instant_app_message is not None:
            self.instant_app_message = instant_app_message
        if instant_app_parameters is not None:
            self.instant_app_parameters = instant_app_parameters
        if instant_app_locale is not None:
            self.instant_app_locale = instant_app_locale
        if delivery_start is not None:
            self.delivery_start = delivery_start
        if snippet_code is not None:
            self.snippet_code = snippet_code
        if on_error_snippet_code is not None:
            self.on_error_snippet_code = on_error_snippet_code
        if upload_id is not None:
            self.upload_id = upload_id
        if complete_conversation is not None:
            self.complete_conversation = complete_conversation
        if escalate_to_agent is not None:
            self.escalate_to_agent = escalate_to_agent
        if escalate_groups is not None:
            self.escalate_groups = escalate_groups
        if call_event_endpoint is not None:
            self.call_event_endpoint = call_event_endpoint
        if event_endpoint_path is not None:
            self.event_endpoint_path = event_endpoint_path
        if assign_to_bot is not None:
            self.assign_to_bot = assign_to_bot
        if is_manual is not None:
            self.is_manual = is_manual
        if delivery_window_start is not None:
            self.delivery_window_start = delivery_window_start
        if delivery_window_end is not None:
            self.delivery_window_end = delivery_window_end
        if use_existing_channels is not None:
            self.use_existing_channels = use_existing_channels
        if match_area_codes is not None:
            self.match_area_codes = match_area_codes
        if minimum_channels is not None:
            self.minimum_channels = minimum_channels
        if is_test_mode is not None:
            self.is_test_mode = is_test_mode
        if description is not None:
            self.description = description
        if is_paused is not None:
            self.is_paused = is_paused
        if primary_folder_id is not None:
            self.primary_folder_id = primary_folder_id

    @property
    def org_channel_ids(self):
        """Gets the org_channel_ids of this AddBulkActionModel.  # noqa: E501

        The org channel apiIds (or internal ids) of the sending channel for message and Instant App actions  # noqa: E501

        :return: The org_channel_ids of this AddBulkActionModel.  # noqa: E501
        :rtype: list[str]
        """
        return self._org_channel_ids

    @org_channel_ids.setter
    def org_channel_ids(self, org_channel_ids):
        """Sets the org_channel_ids of this AddBulkActionModel.

        The org channel apiIds (or internal ids) of the sending channel for message and Instant App actions  # noqa: E501

        :param org_channel_ids: The org_channel_ids of this AddBulkActionModel.  # noqa: E501
        :type: list[str]
        """
        if org_channel_ids is None:
            raise ValueError("Invalid value for `org_channel_ids`, must not be `None`")  # noqa: E501

        self._org_channel_ids = org_channel_ids

    @property
    def contact_lists(self):
        """Gets the contact_lists of this AddBulkActionModel.  # noqa: E501

        The contact list ids containing the contacts to perform the actions on. If a contact is included in multiple lists, they will only be actioned once. The total number of contacts is limited to 20,000.  # noqa: E501

        :return: The contact_lists of this AddBulkActionModel.  # noqa: E501
        :rtype: list[str]
        """
        return self._contact_lists

    @contact_lists.setter
    def contact_lists(self, contact_lists):
        """Sets the contact_lists of this AddBulkActionModel.

        The contact list ids containing the contacts to perform the actions on. If a contact is included in multiple lists, they will only be actioned once. The total number of contacts is limited to 20,000.  # noqa: E501

        :param contact_lists: The contact_lists of this AddBulkActionModel.  # noqa: E501
        :type: list[str]
        """
        if contact_lists is None:
            raise ValueError("Invalid value for `contact_lists`, must not be `None`")  # noqa: E501

        self._contact_lists = contact_lists

    @property
    def message(self):
        """Gets the message of this AddBulkActionModel.  # noqa: E501

        The message to send to the user  # noqa: E501

        :return: The message of this AddBulkActionModel.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this AddBulkActionModel.

        The message to send to the user  # noqa: E501

        :param message: The message of this AddBulkActionModel.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def whisper(self):
        """Gets the whisper of this AddBulkActionModel.  # noqa: E501

        The message to be posted to the conversation so that only agents can see it  # noqa: E501

        :return: The whisper of this AddBulkActionModel.  # noqa: E501
        :rtype: str
        """
        return self._whisper

    @whisper.setter
    def whisper(self, whisper):
        """Sets the whisper of this AddBulkActionModel.

        The message to be posted to the conversation so that only agents can see it  # noqa: E501

        :param whisper: The whisper of this AddBulkActionModel.  # noqa: E501
        :type: str
        """

        self._whisper = whisper

    @property
    def variants(self):
        """Gets the variants of this AddBulkActionModel.  # noqa: E501

        When performing an A/B Test, this provides the list of variations that will be sent to the users  # noqa: E501

        :return: The variants of this AddBulkActionModel.  # noqa: E501
        :rtype: list[AddBulkActionVariantModel]
        """
        return self._variants

    @variants.setter
    def variants(self, variants):
        """Sets the variants of this AddBulkActionModel.

        When performing an A/B Test, this provides the list of variations that will be sent to the users  # noqa: E501

        :param variants: The variants of this AddBulkActionModel.  # noqa: E501
        :type: list[AddBulkActionVariantModel]
        """

        self._variants = variants

    @property
    def retarget(self):
        """Gets the retarget of this AddBulkActionModel.  # noqa: E501


        :return: The retarget of this AddBulkActionModel.  # noqa: E501
        :rtype: BulkActionRetargetModel
        """
        return self._retarget

    @retarget.setter
    def retarget(self, retarget):
        """Sets the retarget of this AddBulkActionModel.


        :param retarget: The retarget of this AddBulkActionModel.  # noqa: E501
        :type: BulkActionRetargetModel
        """

        self._retarget = retarget

    @property
    def instant_app_schema_id(self):
        """Gets the instant_app_schema_id of this AddBulkActionModel.  # noqa: E501

        Optional schema apiId (or internal id) used to create an instance of an Instant App.  # noqa: E501

        :return: The instant_app_schema_id of this AddBulkActionModel.  # noqa: E501
        :rtype: str
        """
        return self._instant_app_schema_id

    @instant_app_schema_id.setter
    def instant_app_schema_id(self, instant_app_schema_id):
        """Sets the instant_app_schema_id of this AddBulkActionModel.

        Optional schema apiId (or internal id) used to create an instance of an Instant App.  # noqa: E501

        :param instant_app_schema_id: The instant_app_schema_id of this AddBulkActionModel.  # noqa: E501
        :type: str
        """

        self._instant_app_schema_id = instant_app_schema_id

    @property
    def instant_app_message(self):
        """Gets the instant_app_message of this AddBulkActionModel.  # noqa: E501

        Invite message to send for the Instant App. The customer link will replace the {link} token or will be placed at the end of the message  # noqa: E501

        :return: The instant_app_message of this AddBulkActionModel.  # noqa: E501
        :rtype: str
        """
        return self._instant_app_message

    @instant_app_message.setter
    def instant_app_message(self, instant_app_message):
        """Sets the instant_app_message of this AddBulkActionModel.

        Invite message to send for the Instant App. The customer link will replace the {link} token or will be placed at the end of the message  # noqa: E501

        :param instant_app_message: The instant_app_message of this AddBulkActionModel.  # noqa: E501
        :type: str
        """

        self._instant_app_message = instant_app_message

    @property
    def instant_app_parameters(self):
        """Gets the instant_app_parameters of this AddBulkActionModel.  # noqa: E501

        Optional Instant App parameters passed into the Instant App  # noqa: E501

        :return: The instant_app_parameters of this AddBulkActionModel.  # noqa: E501
        :rtype: str
        """
        return self._instant_app_parameters

    @instant_app_parameters.setter
    def instant_app_parameters(self, instant_app_parameters):
        """Sets the instant_app_parameters of this AddBulkActionModel.

        Optional Instant App parameters passed into the Instant App  # noqa: E501

        :param instant_app_parameters: The instant_app_parameters of this AddBulkActionModel.  # noqa: E501
        :type: str
        """

        self._instant_app_parameters = instant_app_parameters

    @property
    def instant_app_locale(self):
        """Gets the instant_app_locale of this AddBulkActionModel.  # noqa: E501

        Optional locale for the Instant App  # noqa: E501

        :return: The instant_app_locale of this AddBulkActionModel.  # noqa: E501
        :rtype: str
        """
        return self._instant_app_locale

    @instant_app_locale.setter
    def instant_app_locale(self, instant_app_locale):
        """Sets the instant_app_locale of this AddBulkActionModel.

        Optional locale for the Instant App  # noqa: E501

        :param instant_app_locale: The instant_app_locale of this AddBulkActionModel.  # noqa: E501
        :type: str
        """

        self._instant_app_locale = instant_app_locale

    @property
    def delivery_start(self):
        """Gets the delivery_start of this AddBulkActionModel.  # noqa: E501

        Optional time to start delivering the messages  # noqa: E501

        :return: The delivery_start of this AddBulkActionModel.  # noqa: E501
        :rtype: int
        """
        return self._delivery_start

    @delivery_start.setter
    def delivery_start(self, delivery_start):
        """Sets the delivery_start of this AddBulkActionModel.

        Optional time to start delivering the messages  # noqa: E501

        :param delivery_start: The delivery_start of this AddBulkActionModel.  # noqa: E501
        :type: int
        """

        self._delivery_start = delivery_start

    @property
    def snippet_code(self):
        """Gets the snippet_code of this AddBulkActionModel.  # noqa: E501

        Optional JavaScript Snippet to be executed  # noqa: E501

        :return: The snippet_code of this AddBulkActionModel.  # noqa: E501
        :rtype: str
        """
        return self._snippet_code

    @snippet_code.setter
    def snippet_code(self, snippet_code):
        """Sets the snippet_code of this AddBulkActionModel.

        Optional JavaScript Snippet to be executed  # noqa: E501

        :param snippet_code: The snippet_code of this AddBulkActionModel.  # noqa: E501
        :type: str
        """

        self._snippet_code = snippet_code

    @property
    def on_error_snippet_code(self):
        """Gets the on_error_snippet_code of this AddBulkActionModel.  # noqa: E501

        JavaScript Snippet to be executed the first time an error occurs for each contact  # noqa: E501

        :return: The on_error_snippet_code of this AddBulkActionModel.  # noqa: E501
        :rtype: str
        """
        return self._on_error_snippet_code

    @on_error_snippet_code.setter
    def on_error_snippet_code(self, on_error_snippet_code):
        """Sets the on_error_snippet_code of this AddBulkActionModel.

        JavaScript Snippet to be executed the first time an error occurs for each contact  # noqa: E501

        :param on_error_snippet_code: The on_error_snippet_code of this AddBulkActionModel.  # noqa: E501
        :type: str
        """

        self._on_error_snippet_code = on_error_snippet_code

    @property
    def upload_id(self):
        """Gets the upload_id of this AddBulkActionModel.  # noqa: E501


        :return: The upload_id of this AddBulkActionModel.  # noqa: E501
        :rtype: int
        """
        return self._upload_id

    @upload_id.setter
    def upload_id(self, upload_id):
        """Sets the upload_id of this AddBulkActionModel.


        :param upload_id: The upload_id of this AddBulkActionModel.  # noqa: E501
        :type: int
        """

        self._upload_id = upload_id

    @property
    def complete_conversation(self):
        """Gets the complete_conversation of this AddBulkActionModel.  # noqa: E501


        :return: The complete_conversation of this AddBulkActionModel.  # noqa: E501
        :rtype: bool
        """
        return self._complete_conversation

    @complete_conversation.setter
    def complete_conversation(self, complete_conversation):
        """Sets the complete_conversation of this AddBulkActionModel.


        :param complete_conversation: The complete_conversation of this AddBulkActionModel.  # noqa: E501
        :type: bool
        """

        self._complete_conversation = complete_conversation

    @property
    def escalate_to_agent(self):
        """Gets the escalate_to_agent of this AddBulkActionModel.  # noqa: E501


        :return: The escalate_to_agent of this AddBulkActionModel.  # noqa: E501
        :rtype: bool
        """
        return self._escalate_to_agent

    @escalate_to_agent.setter
    def escalate_to_agent(self, escalate_to_agent):
        """Sets the escalate_to_agent of this AddBulkActionModel.


        :param escalate_to_agent: The escalate_to_agent of this AddBulkActionModel.  # noqa: E501
        :type: bool
        """

        self._escalate_to_agent = escalate_to_agent

    @property
    def escalate_groups(self):
        """Gets the escalate_groups of this AddBulkActionModel.  # noqa: E501


        :return: The escalate_groups of this AddBulkActionModel.  # noqa: E501
        :rtype: list[int]
        """
        return self._escalate_groups

    @escalate_groups.setter
    def escalate_groups(self, escalate_groups):
        """Sets the escalate_groups of this AddBulkActionModel.


        :param escalate_groups: The escalate_groups of this AddBulkActionModel.  # noqa: E501
        :type: list[int]
        """

        self._escalate_groups = escalate_groups

    @property
    def call_event_endpoint(self):
        """Gets the call_event_endpoint of this AddBulkActionModel.  # noqa: E501


        :return: The call_event_endpoint of this AddBulkActionModel.  # noqa: E501
        :rtype: bool
        """
        return self._call_event_endpoint

    @call_event_endpoint.setter
    def call_event_endpoint(self, call_event_endpoint):
        """Sets the call_event_endpoint of this AddBulkActionModel.


        :param call_event_endpoint: The call_event_endpoint of this AddBulkActionModel.  # noqa: E501
        :type: bool
        """

        self._call_event_endpoint = call_event_endpoint

    @property
    def event_endpoint_path(self):
        """Gets the event_endpoint_path of this AddBulkActionModel.  # noqa: E501


        :return: The event_endpoint_path of this AddBulkActionModel.  # noqa: E501
        :rtype: str
        """
        return self._event_endpoint_path

    @event_endpoint_path.setter
    def event_endpoint_path(self, event_endpoint_path):
        """Sets the event_endpoint_path of this AddBulkActionModel.


        :param event_endpoint_path: The event_endpoint_path of this AddBulkActionModel.  # noqa: E501
        :type: str
        """

        self._event_endpoint_path = event_endpoint_path

    @property
    def assign_to_bot(self):
        """Gets the assign_to_bot of this AddBulkActionModel.  # noqa: E501


        :return: The assign_to_bot of this AddBulkActionModel.  # noqa: E501
        :rtype: int
        """
        return self._assign_to_bot

    @assign_to_bot.setter
    def assign_to_bot(self, assign_to_bot):
        """Sets the assign_to_bot of this AddBulkActionModel.


        :param assign_to_bot: The assign_to_bot of this AddBulkActionModel.  # noqa: E501
        :type: int
        """

        self._assign_to_bot = assign_to_bot

    @property
    def is_manual(self):
        """Gets the is_manual of this AddBulkActionModel.  # noqa: E501


        :return: The is_manual of this AddBulkActionModel.  # noqa: E501
        :rtype: bool
        """
        return self._is_manual

    @is_manual.setter
    def is_manual(self, is_manual):
        """Sets the is_manual of this AddBulkActionModel.


        :param is_manual: The is_manual of this AddBulkActionModel.  # noqa: E501
        :type: bool
        """

        self._is_manual = is_manual

    @property
    def delivery_window_start(self):
        """Gets the delivery_window_start of this AddBulkActionModel.  # noqa: E501

        Start of the window for what time of day messages can be sent  # noqa: E501

        :return: The delivery_window_start of this AddBulkActionModel.  # noqa: E501
        :rtype: int
        """
        return self._delivery_window_start

    @delivery_window_start.setter
    def delivery_window_start(self, delivery_window_start):
        """Sets the delivery_window_start of this AddBulkActionModel.

        Start of the window for what time of day messages can be sent  # noqa: E501

        :param delivery_window_start: The delivery_window_start of this AddBulkActionModel.  # noqa: E501
        :type: int
        """

        self._delivery_window_start = delivery_window_start

    @property
    def delivery_window_end(self):
        """Gets the delivery_window_end of this AddBulkActionModel.  # noqa: E501

        End of the window for what time of day messages can be sent  # noqa: E501

        :return: The delivery_window_end of this AddBulkActionModel.  # noqa: E501
        :rtype: int
        """
        return self._delivery_window_end

    @delivery_window_end.setter
    def delivery_window_end(self, delivery_window_end):
        """Sets the delivery_window_end of this AddBulkActionModel.

        End of the window for what time of day messages can be sent  # noqa: E501

        :param delivery_window_end: The delivery_window_end of this AddBulkActionModel.  # noqa: E501
        :type: int
        """

        self._delivery_window_end = delivery_window_end

    @property
    def use_existing_channels(self):
        """Gets the use_existing_channels of this AddBulkActionModel.  # noqa: E501

        If a prior conversational history exists with a customer, prioritize use of their last used channel if possible  # noqa: E501

        :return: The use_existing_channels of this AddBulkActionModel.  # noqa: E501
        :rtype: bool
        """
        return self._use_existing_channels

    @use_existing_channels.setter
    def use_existing_channels(self, use_existing_channels):
        """Sets the use_existing_channels of this AddBulkActionModel.

        If a prior conversational history exists with a customer, prioritize use of their last used channel if possible  # noqa: E501

        :param use_existing_channels: The use_existing_channels of this AddBulkActionModel.  # noqa: E501
        :type: bool
        """

        self._use_existing_channels = use_existing_channels

    @property
    def match_area_codes(self):
        """Gets the match_area_codes of this AddBulkActionModel.  # noqa: E501

        Match the outgoing number area codes to the customer's area code if possible  # noqa: E501

        :return: The match_area_codes of this AddBulkActionModel.  # noqa: E501
        :rtype: bool
        """
        return self._match_area_codes

    @match_area_codes.setter
    def match_area_codes(self, match_area_codes):
        """Sets the match_area_codes of this AddBulkActionModel.

        Match the outgoing number area codes to the customer's area code if possible  # noqa: E501

        :param match_area_codes: The match_area_codes of this AddBulkActionModel.  # noqa: E501
        :type: bool
        """

        self._match_area_codes = match_area_codes

    @property
    def minimum_channels(self):
        """Gets the minimum_channels of this AddBulkActionModel.  # noqa: E501

        The minimum amount of channels this bulk action will operate on at a time. Defaults to 1. Must be less than or equal to the total number of channels  # noqa: E501

        :return: The minimum_channels of this AddBulkActionModel.  # noqa: E501
        :rtype: int
        """
        return self._minimum_channels

    @minimum_channels.setter
    def minimum_channels(self, minimum_channels):
        """Sets the minimum_channels of this AddBulkActionModel.

        The minimum amount of channels this bulk action will operate on at a time. Defaults to 1. Must be less than or equal to the total number of channels  # noqa: E501

        :param minimum_channels: The minimum_channels of this AddBulkActionModel.  # noqa: E501
        :type: int
        """

        self._minimum_channels = minimum_channels

    @property
    def is_test_mode(self):
        """Gets the is_test_mode of this AddBulkActionModel.  # noqa: E501

        Test Mode. All messages will instead be sent as whispers rather than being sent via text  # noqa: E501

        :return: The is_test_mode of this AddBulkActionModel.  # noqa: E501
        :rtype: bool
        """
        return self._is_test_mode

    @is_test_mode.setter
    def is_test_mode(self, is_test_mode):
        """Sets the is_test_mode of this AddBulkActionModel.

        Test Mode. All messages will instead be sent as whispers rather than being sent via text  # noqa: E501

        :param is_test_mode: The is_test_mode of this AddBulkActionModel.  # noqa: E501
        :type: bool
        """

        self._is_test_mode = is_test_mode

    @property
    def description(self):
        """Gets the description of this AddBulkActionModel.  # noqa: E501

        A name or short description of the bulk action or campaign  # noqa: E501

        :return: The description of this AddBulkActionModel.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this AddBulkActionModel.

        A name or short description of the bulk action or campaign  # noqa: E501

        :param description: The description of this AddBulkActionModel.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def is_paused(self):
        """Gets the is_paused of this AddBulkActionModel.  # noqa: E501

        If this bulk action should start in a paused state  # noqa: E501

        :return: The is_paused of this AddBulkActionModel.  # noqa: E501
        :rtype: bool
        """
        return self._is_paused

    @is_paused.setter
    def is_paused(self, is_paused):
        """Sets the is_paused of this AddBulkActionModel.

        If this bulk action should start in a paused state  # noqa: E501

        :param is_paused: The is_paused of this AddBulkActionModel.  # noqa: E501
        :type: bool
        """

        self._is_paused = is_paused

    @property
    def primary_folder_id(self):
        """Gets the primary_folder_id of this AddBulkActionModel.  # noqa: E501

        The primary actions folder of the bulk action or campaign  # noqa: E501

        :return: The primary_folder_id of this AddBulkActionModel.  # noqa: E501
        :rtype: int
        """
        return self._primary_folder_id

    @primary_folder_id.setter
    def primary_folder_id(self, primary_folder_id):
        """Sets the primary_folder_id of this AddBulkActionModel.

        The primary actions folder of the bulk action or campaign  # noqa: E501

        :param primary_folder_id: The primary_folder_id of this AddBulkActionModel.  # noqa: E501
        :type: int
        """

        self._primary_folder_id = primary_folder_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AddBulkActionModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddBulkActionModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AddTeamMemberModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'email': 'str',
        'display_name': 'str',
        'user_type': 'str',
        'is_admin': 'bool',
        'send_welcome_email': 'bool',
        'app_mode': 'str',
        'create_or_find': 'bool'
    }

    attribute_map = {
        'email': 'email',
        'display_name': 'displayName',
        'user_type': 'userType',
        'is_admin': 'isAdmin',
        'send_welcome_email': 'sendWelcomeEmail',
        'app_mode': 'appMode',
        'create_or_find': 'createOrFind'
    }

    def __init__(self, email=None, display_name=None, user_type=None, is_admin=None, send_welcome_email=None, app_mode=None, create_or_find=None):  # noqa: E501
        """AddTeamMemberModel - a model defined in Swagger"""  # noqa: E501
        self._email = None
        self._display_name = None
        self._user_type = None
        self._is_admin = None
        self._send_welcome_email = None
        self._app_mode = None
        self._create_or_find = None
        self.discriminator = None
        if email is not None:
            self.email = email
        if display_name is not None:
            self.display_name = display_name
        if user_type is not None:
            self.user_type = user_type
        if is_admin is not None:
            self.is_admin = is_admin
        if send_welcome_email is not None:
            self.send_welcome_email = send_welcome_email
        if app_mode is not None:
            self.app_mode = app_mode
        if create_or_find is not None:
            self.create_or_find = create_or_find

    @property
    def email(self):
        """Gets the email of this AddTeamMemberModel.  # noqa: E501

        The email address of this team member.  # noqa: E501

        :return: The email of this AddTeamMemberModel.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this AddTeamMemberModel.

        The email address of this team member.  # noqa: E501

        :param email: The email of this AddTeamMemberModel.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def display_name(self):
        """Gets the display_name of this AddTeamMemberModel.  # noqa: E501

        The display name of this user.  # noqa: E501

        :return: The display_name of this AddTeamMemberModel.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this AddTeamMemberModel.

        The display name of this user.  # noqa: E501

        :param display_name: The display_name of this AddTeamMemberModel.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def user_type(self):
        """Gets the user_type of this AddTeamMemberModel.  # noqa: E501

        The user type for this team member.  # noqa: E501

        :return: The user_type of this AddTeamMemberModel.  # noqa: E501
        :rtype: str
        """
        return self._user_type

    @user_type.setter
    def user_type(self, user_type):
        """Sets the user_type of this AddTeamMemberModel.

        The user type for this team member.  # noqa: E501

        :param user_type: The user_type of this AddTeamMemberModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["TEAM_MEMBER", "CUSTOMER", "BOT", "SYSTEM", "TROUBLESHOOTING", "INSTANT_APP"]  # noqa: E501
        if user_type not in allowed_values:
            raise ValueError(
                "Invalid value for `user_type` ({0}), must be one of {1}"  # noqa: E501
                .format(user_type, allowed_values)
            )

        self._user_type = user_type

    @property
    def is_admin(self):
        """Gets the is_admin of this AddTeamMemberModel.  # noqa: E501

        Make this user to be an admin in the system  # noqa: E501

        :return: The is_admin of this AddTeamMemberModel.  # noqa: E501
        :rtype: bool
        """
        return self._is_admin

    @is_admin.setter
    def is_admin(self, is_admin):
        """Sets the is_admin of this AddTeamMemberModel.

        Make this user to be an admin in the system  # noqa: E501

        :param is_admin: The is_admin of this AddTeamMemberModel.  # noqa: E501
        :type: bool
        """

        self._is_admin = is_admin

    @property
    def send_welcome_email(self):
        """Gets the send_welcome_email of this AddTeamMemberModel.  # noqa: E501

        Whether a welcome email should be sent to the new team member  # noqa: E501

        :return: The send_welcome_email of this AddTeamMemberModel.  # noqa: E501
        :rtype: bool
        """
        return self._send_welcome_email

    @send_welcome_email.setter
    def send_welcome_email(self, send_welcome_email):
        """Sets the send_welcome_email of this AddTeamMemberModel.

        Whether a welcome email should be sent to the new team member  # noqa: E501

        :param send_welcome_email: The send_welcome_email of this AddTeamMemberModel.  # noqa: E501
        :type: bool
        """

        self._send_welcome_email = send_welcome_email

    @property
    def app_mode(self):
        """Gets the app_mode of this AddTeamMemberModel.  # noqa: E501

        Sets which mode the user should be in during first Login. Currently accepts 'spark' or 'classic'. If blank, we use the server default.  # noqa: E501

        :return: The app_mode of this AddTeamMemberModel.  # noqa: E501
        :rtype: str
        """
        return self._app_mode

    @app_mode.setter
    def app_mode(self, app_mode):
        """Sets the app_mode of this AddTeamMemberModel.

        Sets which mode the user should be in during first Login. Currently accepts 'spark' or 'classic'. If blank, we use the server default.  # noqa: E501

        :param app_mode: The app_mode of this AddTeamMemberModel.  # noqa: E501
        :type: str
        """

        self._app_mode = app_mode

    @property
    def create_or_find(self):
        """Gets the create_or_find of this AddTeamMemberModel.  # noqa: E501

        Whether to return the existing team member instead of an error if the team member already exists  # noqa: E501

        :return: The create_or_find of this AddTeamMemberModel.  # noqa: E501
        :rtype: bool
        """
        return self._create_or_find

    @create_or_find.setter
    def create_or_find(self, create_or_find):
        """Sets the create_or_find of this AddTeamMemberModel.

        Whether to return the existing team member instead of an error if the team member already exists  # noqa: E501

        :param create_or_find: The create_or_find of this AddTeamMemberModel.  # noqa: E501
        :type: bool
        """

        self._create_or_find = create_or_find

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AddTeamMemberModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddTeamMemberModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.bots_api import BotsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestBotsApi(unittest.TestCase):
    """BotsApi unit test stubs"""

    def setUp(self):
        self.api = BotsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_bot(self):
        """Test case for create_bot

        Creates a new bot  # noqa: E501
        """
        pass

    def test_delete_bot(self):
        """Test case for delete_bot

        Deletes a bot  # noqa: E501
        """
        pass

    def test_get_bot(self):
        """Test case for get_bot

        Gets a bot  # noqa: E501
        """
        pass

    def test_get_bot_intents(self):
        """Test case for get_bot_intents

        Gets all intents of a bot  # noqa: E501
        """
        pass

    def test_get_bots(self):
        """Test case for get_bots

        Gets all bots for the org.  # noqa: E501
        """
        pass

    def test_update_bot(self):
        """Test case for update_bot

        Updates an existing bot  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
